@@ -1,10 +1,8 @@
 package org.herac.tuxguitar.android.action.impl.browser;
 
 import org.herac.tuxguitar.action.TGActionContext;
-import org.herac.tuxguitar.action.TGActionException;
 import org.herac.tuxguitar.android.action.TGActionBase;
 import org.herac.tuxguitar.android.browser.model.TGBrowserElement;
-import org.herac.tuxguitar.android.browser.model.TGBrowserException;
 import org.herac.tuxguitar.android.browser.model.TGBrowserSession;
 import org.herac.tuxguitar.util.TGContext;
 
@@ -20,14 +18,14 @@ public class TGBrowserCdElementAction extends TGActionBase{
 	}
 	
 	protected void processAction(final TGActionContext context) {
-		try {
-			TGBrowserSession tgBrowserSession = (TGBrowserSession) context.getAttribute(ATTRIBUTE_SESSION);
-			if( tgBrowserSession.getBrowser() != null ) {
-				TGBrowserElement tgBrowserElement = (TGBrowserElement) context.getAttribute(ATTRIBUTE_ELEMENT);
-				tgBrowserSession.getBrowser().cdElement(tgBrowserElement);
-			}
-		} catch (TGBrowserException e)  {
-			throw new TGActionException(e);
+		TGBrowserSession tgBrowserSession = context.getAttribute(ATTRIBUTE_SESSION);
+		if( tgBrowserSession.getBrowser() != null ) {
+			TGBrowserElement tgBrowserElement = context.getAttribute(ATTRIBUTE_ELEMENT);
+			tgBrowserSession.getBrowser().cdElement(new TGBrowserActionCallBack<Object>(this, context) {
+				public void onActionSuccess(TGActionContext context, Object successData) {
+					// nothing to do
+				}
+			}, tgBrowserElement);
 		}
 	}
 }
