@@ -1,9 +1,7 @@
 package org.herac.tuxguitar.android.action.impl.browser;
 
 import org.herac.tuxguitar.action.TGActionContext;
-import org.herac.tuxguitar.action.TGActionException;
 import org.herac.tuxguitar.android.action.TGActionBase;
-import org.herac.tuxguitar.android.browser.model.TGBrowserException;
 import org.herac.tuxguitar.android.browser.model.TGBrowserSession;
 import org.herac.tuxguitar.util.TGContext;
 
@@ -18,13 +16,13 @@ public class TGBrowserCdUpAction extends TGActionBase{
 	}
 	
 	protected void processAction(final TGActionContext context) {
-		try {
-			TGBrowserSession tgBrowserSession = (TGBrowserSession) context.getAttribute(ATTRIBUTE_SESSION);
-			if( tgBrowserSession.getBrowser() != null ) {
-				tgBrowserSession.getBrowser().cdUp();
-			}
-		} catch (TGBrowserException e)  {
-			throw new TGActionException(e);
+		TGBrowserSession tgBrowserSession = context.getAttribute(ATTRIBUTE_SESSION);
+		if( tgBrowserSession.getBrowser() != null ) {
+			tgBrowserSession.getBrowser().cdUp(new TGBrowserActionCallBack<Object>(this, context) {
+				public void onActionSuccess(TGActionContext context, Object successData) {
+					// nothing to do
+				}
+			});
 		}
 	}
 }
