@@ -20,7 +20,7 @@ public class TGBrowserRemoveCollectionAction extends TGActionBase{
 	
 	protected void processAction(final TGActionContext context) {
 		try {
-			TGBrowserCollection collection = (TGBrowserCollection) context.getAttribute(ATTRIBUTE_COLLECTION);
+			TGBrowserCollection collection = context.getAttribute(ATTRIBUTE_COLLECTION);
 			TGBrowserManager browserManager = TGBrowserManager.getInstance(getContext());
 			
 			browserManager.removeCollection(collection);
