@@ -1,6 +1,7 @@
 package org.herac.tuxguitar.android.action.listener.cache.controller;
 
 import org.herac.tuxguitar.action.TGActionContext;
+import org.herac.tuxguitar.editor.undo.TGUndoableManager;
 import org.herac.tuxguitar.util.TGContext;
 
 public class TGUpdateLoadedSongController extends TGUpdateItemsController {
@@ -11,6 +12,8 @@ public class TGUpdateLoadedSongController extends TGUpdateItemsController {
 
 	@Override
 	public void update(TGContext context, TGActionContext actionContext) {
+		TGUndoableManager.getInstance(context).discardAllEdits();
+
 		this.findUpdateBuffer(context).requestUpdateLoadedSong();
 		
 		super.update(context, actionContext);
