@@ -1,7 +1,8 @@
 package org.herac.tuxguitar.android.action.listener.cache.controller;
 
 import org.herac.tuxguitar.action.TGActionContext;
-import org.herac.tuxguitar.android.TuxGuitar;
+import org.herac.tuxguitar.android.transport.TGTransport;
+import org.herac.tuxguitar.player.base.MidiPlayer;
 import org.herac.tuxguitar.util.TGContext;
 
 public class TGUpdateTransportPositionController extends TGUpdateItemsController {
@@ -12,9 +13,9 @@ public class TGUpdateTransportPositionController extends TGUpdateItemsController
 	
 	@Override
 	public void update(TGContext context, TGActionContext actionContext) {
-		TuxGuitar tuxguitar = TuxGuitar.getInstance(context);
-		if( tuxguitar.getPlayer().isRunning()) {
-			tuxguitar.getTransport().gotoCaretPosition();
+		MidiPlayer midiPlayer = MidiPlayer.getInstance(context);
+		if( midiPlayer.isRunning()) {
+			TGTransport.getInstance(context).gotoCaretPosition();
 		}
 		
 		// Call super update.
