@@ -3,8 +3,6 @@ package org.herac.tuxguitar.android.browser.assets;
 import java.util.Comparator;
 
 import org.herac.tuxguitar.android.browser.model.TGBrowserElement;
-import org.herac.tuxguitar.android.browser.model.TGBrowserException;
-import org.herac.tuxguitar.util.TGException;
 
 public class TGAssetBrowserElementComparator implements Comparator<TGBrowserElement> {
 	
@@ -17,17 +15,13 @@ public class TGAssetBrowserElementComparator implements Comparator<TGBrowserElem
 	private static final int DIRECTION_FOLDER = 1;
 	
 	public int compare(TGBrowserElement element1, TGBrowserElement element2) {
-		try {
-			if(element1.isFolder() && !element2.isFolder()){
-				return (DIRECTION_FOLDER * RESULT_LESS);
-			}
-			if(element2.isFolder() && !element1.isFolder()){
-				return (DIRECTION_FOLDER * RESULT_GREATER);
-			}
-			
-			return (DIRECTION * (element1.getName().compareTo(element2.getName())));
-		} catch (TGBrowserException e) {
-			throw new TGException(e);
+		if( element1.isFolder() && !element2.isFolder() ){
+			return (DIRECTION_FOLDER * RESULT_LESS);
 		}
+		if( element2.isFolder() && !element1.isFolder() ){
+			return (DIRECTION_FOLDER * RESULT_GREATER);
+		}
+		
+		return (DIRECTION * (element1.getName().compareTo(element2.getName())));
 	}
 }
