@@ -1,9 +1,8 @@
 package org.herac.tuxguitar.android.browser.filesystem;
 
-import org.herac.tuxguitar.android.browser.model.TGBrowserException;
 import org.herac.tuxguitar.android.browser.model.TGBrowserFactorySettingsHandler;
 
 public interface TGFsBrowserSettingsFactory {
 	
-	void createSettings(TGBrowserFactorySettingsHandler handler) throws TGBrowserException;
+	void createSettings(TGBrowserFactorySettingsHandler handler);
 }
