@@ -9,12 +9,12 @@ public class ModifiedMarkerPlugin implements TGPlugin {
 	
 	private ModifiedMarker modifiedMarker;
 	
-	public void setEnabled(boolean enabled) throws TGPluginException {
+	public void setEnabled(TGContext context, boolean enabled) throws TGPluginException {
 		try {
 			if( this.modifiedMarker != null ){
 				this.modifiedMarker.setEnabled(enabled);
 			}else if(enabled){
-				this.modifiedMarker = new ModifiedMarker();
+				this.modifiedMarker = new ModifiedMarker(context);
 				this.modifiedMarker.setEnabled(true);
 				this.modifiedMarker.init();
 			}
@@ -28,10 +28,10 @@ public class ModifiedMarkerPlugin implements TGPlugin {
 	}
 	
 	public void connect(TGContext context) throws TGPluginException {
-		this.setEnabled(true);
+		this.setEnabled(context, true);
 	}
 
 	public void disconnect(TGContext context) throws TGPluginException {
-		this.setEnabled(false);
+		this.setEnabled(context, false);
 	}
 }
