@@ -1,7 +1,8 @@
 package org.herac.tuxguitar.cocoa.toolbar;
 
-import org.herac.tuxguitar.app.TuxGuitar;
+import org.herac.tuxguitar.app.view.main.TGWindow;
 import org.herac.tuxguitar.cocoa.TGCocoaIntegrationPlugin;
+import org.herac.tuxguitar.ui.swt.widget.SWTWindow;
 import org.herac.tuxguitar.util.TGContext;
 import org.herac.tuxguitar.util.plugin.TGPlugin;
 import org.herac.tuxguitar.util.plugin.TGPluginException;
@@ -21,7 +22,7 @@ public class MacToolbarPlugin implements TGPlugin {
 			 }else {
 				this.macToolbar = new MacToolbar();
 				this.macToolbar.setEnabled(true);
-				this.macToolbar.init( TuxGuitar.getInstance().getShell() );
+				this.macToolbar.init(((SWTWindow) TGWindow.getInstance(context).getWindow()).getControl());
 			}
 		} catch( Throwable throwable ){
 			throw new TGPluginException( throwable );
