@@ -21,11 +21,15 @@ public class GMSynthesizer implements MidiSynthesizer{
 		}
 	}
 	
-	public MidiChannel openChannel(int channelId){
+	public MidiChannel openChannel(int channelId) throws MidiPlayerException {
 		return new GMChannel(channelId, this.gmChannelRouter, this.midiOutputPort.getReceiver());
 	}
 
 	public boolean isChannelOpen(MidiChannel midiChannel) throws MidiPlayerException {
 		return true;
 	}
+
+	public GMChannelRouter getChannelRouter() {
+		return this.gmChannelRouter;
+	}
 }
