@@ -4,15 +4,14 @@ import java.util.ArrayList;
 import java.util.Iterator;
 import java.util.List;
 
-import org.herac.tuxguitar.graphics.TGColor;
-import org.herac.tuxguitar.graphics.TGPainter;
-import org.herac.tuxguitar.graphics.TGRectangle;
 import org.herac.tuxguitar.song.managers.TGSongManager;
 import org.herac.tuxguitar.song.models.TGDuration;
 import org.herac.tuxguitar.song.models.TGMeasure;
 import org.herac.tuxguitar.song.models.TGMeasureHeader;
-import org.herac.tuxguitar.song.models.TGNote;
 import org.herac.tuxguitar.song.models.TGSong;
+import org.herac.tuxguitar.ui.resource.UIColor;
+import org.herac.tuxguitar.ui.resource.UIPainter;
+import org.herac.tuxguitar.ui.resource.UIRectangle;
 
 public abstract class TGLayout {
 	
@@ -42,6 +41,12 @@ public abstract class TGLayout {
 	private float trackSpacing;
 	private float firstTrackSpacing;
 	private float firstMeasureSpacing;
+	private float firstNoteSpacing;
+	private float measureLeftSpacing;
+	private float measureRightSpacing;
+	private float clefSpacing;
+	private float keySignatureSpacing;
+	private float timeSignatureSpacing;
 	private float chordFretIndexSpacing;
 	private float chordStringSpacing;
 	private float chordFretSpacing;
@@ -53,21 +58,22 @@ public abstract class TGLayout {
 	private float textSpacing;
 	private float markerSpacing;
 	private float loopMarkerSpacing;
+	private float[] lineWidths;
+	private float[] durationWidths;
 	private boolean bufferEnabled;
 	private boolean playModeEnabled;
+	private boolean tabNotePathRendererEnabled;
 	
 	private List<TrackPosition> trackPositions;
 	
 	private TGController controller;
 	private TGResources resources;
-	private TGLayoutStyles styles;
 	
 	public TGLayout(TGController controller,int style){
 		this.controller = controller;
 		this.trackPositions = new ArrayList<TrackPosition>();
 		this.playModeEnabled = false;
 		this.resources = new TGResources(this);
-		this.styles = new TGLayoutStyles();
 		this.style = style;
 		if((this.style & DISPLAY_TABLATURE) == 0 && (this.style & DISPLAY_SCORE) == 0 ){
 			this.style |= DISPLAY_TABLATURE;
@@ -83,43 +89,62 @@ public abstract class TGLayout {
 	}
 	
 	public void loadStyles(float scale, float fontScale){
-		this.setScale(scale);
-		this.setFontScale(fontScale);
-		this.getComponent().configureStyles(this.styles);
+		TGLayoutStyles styles = this.getComponent().getStyles();
 		
-		this.setBufferEnabled( this.styles.isBufferEnabled() );
-		this.setStringSpacing( (this.styles.getStringSpacing() * getScale() ) );
-		this.setScoreLineSpacing( (this.styles.getScoreLineSpacing() * getScale() ) );
-		this.setFirstMeasureSpacing( (this.styles.getFirstMeasureSpacing() * getScale() ) );
-		this.setMinBufferSeparator( (this.styles.getMinBufferSeparator() * getScale() ) );
-		this.setMinTopSpacing( (this.styles.getMinTopSpacing() * getScale() ) );
-		this.setMinScoreTabSpacing( (this.styles.getMinScoreTabSpacing() * getScale() ) );
-		this.setFirstTrackSpacing( (this.styles.getFirstTrackSpacing() * getScale() ) );
-		this.setTrackSpacing( (this.styles.getTrackSpacing() * getScale() ) );
-		this.setChordFretIndexSpacing( (this.styles.getChordFretIndexSpacing() * getScale() ) );
-		this.setChordStringSpacing( (this.styles.getChordStringSpacing() * getScale() ) );
-		this.setChordFretSpacing( (this.styles.getChordFretSpacing() * getScale() ) );
-		this.setChordNoteSize( (this.styles.getChordNoteSize() * getScale() ) );
-		this.setChordLineWidth( (this.styles.getChordLineWidth() * getScale() ) );
-		this.setRepeatEndingSpacing( (this.styles.getRepeatEndingSpacing() * getScale() ) );
-		this.setTextSpacing( (this.styles.getTextSpacing() * getScale() ) );
-		this.setMarkerSpacing( (this.styles.getMarkerSpacing() * getScale() ) );
-		this.setLoopMarkerSpacing( (this.styles.getLoopMarkerSpacing() * getScale() ) );
-		this.setDivisionTypeSpacing( (this.styles.getDivisionTypeSpacing() * getScale() ) );
-		this.setEffectSpacing( (this.styles.getEffectSpacing() * getScale() ) );
-		this.getResources().load(this.styles);
+		this.scale = scale;
+		this.fontScale = fontScale;
+		
+		this.bufferEnabled = styles.isBufferEnabled();
+		this.tabNotePathRendererEnabled = styles.isTabNotePathRendererEnabled();
+		this.stringSpacing = (styles.getStringSpacing() * getScale());
+		this.scoreLineSpacing = (styles.getScoreLineSpacing() * getScale());
+		this.minBufferSeparator = (styles.getMinBufferSeparator() * getScale());
+		this.minTopSpacing = (styles.getMinTopSpacing() * getScale());
+		this.minScoreTabSpacing = (styles.getMinScoreTabSpacing() * getScale());
+		this.firstTrackSpacing = (styles.getFirstTrackSpacing() * getScale());
+		this.firstMeasureSpacing = (styles.getFirstMeasureSpacing() * getScale());
+		this.firstNoteSpacing = (styles.getFirstNoteSpacing() * getScale());
+		this.measureLeftSpacing = (styles.getMeasureLeftSpacing() * getScale());
+		this.measureRightSpacing = (styles.getMeasureRightSpacing() * getScale());
+		this.clefSpacing = (styles.getClefSpacing() * getScale());
+		this.keySignatureSpacing = (styles.getKeySignatureSpacing() * getScale());
+		this.timeSignatureSpacing = (styles.getTimeSignatureSpacing() * getScale());		
+		this.trackSpacing = (styles.getTrackSpacing() * getScale());
+		this.chordFretIndexSpacing = (styles.getChordFretIndexSpacing() * getScale());
+		this.chordStringSpacing = (styles.getChordStringSpacing() * getScale());
+		this.chordFretSpacing = (styles.getChordFretSpacing() * getScale());
+		this.chordNoteSize = (styles.getChordNoteSize() * getScale());
+		this.chordLineWidth = (styles.getChordLineWidth() * getScale());
+		this.repeatEndingSpacing = (styles.getRepeatEndingSpacing() * getScale());
+		this.textSpacing = (styles.getTextSpacing() * getScale());
+		this.markerSpacing = (styles.getMarkerSpacing() * getScale());
+		this.loopMarkerSpacing = (styles.getLoopMarkerSpacing() * getScale());
+		this.divisionTypeSpacing = (styles.getDivisionTypeSpacing() * getScale());
+		this.effectSpacing = (styles.getEffectSpacing() * getScale());
+		
+		this.lineWidths = new float[styles.getLineWidths() != null ? styles.getLineWidths().length : 0];
+		for(int i = 0 ; i < this.lineWidths.length; i ++) {
+			this.lineWidths[i] = (styles.getLineWidths()[i] * getScale());
+		}
+		
+		this.durationWidths = new float[styles.getDurationWidths() != null ? styles.getDurationWidths().length : 0];
+		for(int i = 0 ; i < this.durationWidths.length; i ++) {
+			this.durationWidths[i] = (styles.getDurationWidths()[i] * getScale());
+		}
+		
+		this.getResources().load(styles);
 	}
 	
-	public abstract void paintSong(TGPainter painter,TGRectangle clientArea,float fromX,float fromY);
+	public abstract void paintSong(UIPainter painter,UIRectangle clientArea,float fromX,float fromY);
 	
 	public abstract int getMode();
 	
-	public void paint(TGPainter painter,TGRectangle clientArea,float fromX,float fromY){
+	public void paint(UIPainter painter,UIRectangle clientArea,float fromX,float fromY){
 		this.playModeEnabled = false;
 		paintSong(painter,clientArea,fromX,fromY);
 	}
 	
-	public void paintMeasure(TGMeasureImpl measure,TGPainter painter,float spacing) {
+	public void paintMeasure(TGMeasureImpl measure,UIPainter painter,float spacing) {
 		measure.setSpacing(spacing);
 		measure.paintMeasure(this, painter);
 	}
@@ -168,7 +193,7 @@ public abstract class TGLayout {
 	/**
 	 * Pinta las lineas
 	 */
-	public void paintLines(TGTrackImpl track,TGTrackSpacing ts,TGPainter painter,float x,float y,float width) {
+	public void paintLines(TGTrackImpl track,TGTrackSpacing ts,UIPainter painter,float x,float y,float width) {
 		if(width > 0){
 			setLineStyle(painter);
 			float tempX = ((x < 0)?0:x);
@@ -206,13 +231,12 @@ public abstract class TGLayout {
 	/**
 	 * Pinta el compas y las notas que estan sonando
 	 */
-	public void paintPlayMode(TGPainter painter,TGMeasureImpl measure,TGBeatImpl beat,boolean paintMeasure){
+	public void paintPlayMode(UIPainter painter, TGMeasureImpl measure, TGBeatImpl beat){
 		this.playModeEnabled = true;
 		
 		//pinto el compas
-		if( paintMeasure ){
-			measure.paintMeasure(this,painter);
-		}
+		measure.paintPlayMode(this, painter);
+		
 		//pinto el pulso
 		if( beat != null ){
 			beat.paint(this,painter,measure.getPosX()  + measure.getHeaderImpl().getLeftSpacing(this), measure.getPosY());
@@ -224,6 +248,13 @@ public abstract class TGLayout {
 		this.playModeEnabled = false;
 	}
 	
+	public void fillBackground(UIPainter painter, UIRectangle area) {
+		painter.setBackground(this.getLightColor(this.getResources().getBackgroundColor()));
+		painter.initPath(UIPainter.PATH_FILL);
+		painter.addRectangle(area.getX(), area.getY(), area.getWidth(), area.getHeight());
+		painter.closePath();
+	}
+	
 	protected float checkScale(){
 		float v1 = ((this.style & DISPLAY_SCORE) != 0 ? (getScoreLineSpacing() * 1.25f ) : 0 );
 		float v2 = ((this.style & DISPLAY_TABLATURE) != 0 ? getStringSpacing() : 0 );
@@ -258,57 +289,40 @@ public abstract class TGLayout {
 	 * Calcula el espacio minimo entre negras, dependiendo de la duracion de la nota 
 	 */
 	public float getSpacingForQuarter(TGDuration duration){
-		return (((float)TGDuration.QUARTER_TIME / (float)duration.getTime()) * getMinSpacing(duration));
+		return (((float)TGDuration.QUARTER_TIME / (float)duration.getTime()) * getDurationWidth(duration));
 	}
 	
-	/**
-	 * Calcula el Espacio minimo que quedara entre nota y nota
-	 */
-	protected float getMinSpacing(TGDuration duration){
-		float scale = getScale();
-		switch(duration.getValue()){
-			case TGDuration.WHOLE:
-				return (50.0f * scale);
-			case TGDuration.HALF:
-				return (30.0f * scale);
-			case TGDuration.QUARTER:
-				return (25.0f * scale);
-			case TGDuration.EIGHTH:
-				return (20.0f * scale);
-			default:
-				return (18.0f * scale);
-		}
-	}
-	
-	public float getMinBeatWidth() {
-		return (17.0f * getScale());
-	}
-	
-	/**
-	 * Calcula el Espacio que ocupara el pulso
-	 */
-	public float getVoiceWidth(TGVoiceImpl voice){
-		float scale = getScale();
-		TGDuration duration = voice.getDuration();
-		if(duration != null){
-			switch(duration.getValue()){
-				case TGDuration.WHOLE:
-					return (30.0f * scale);
-				case TGDuration.HALF:
-					return (25.0f * scale);
-				case TGDuration.QUARTER:
-					return (21.0f * scale);
-				case TGDuration.EIGHTH:
-					return (20.0f * scale);
-				case TGDuration.SIXTEENTH:
-					return (19.0f * scale);
-				case TGDuration.THIRTY_SECOND:
-					return (18.0f * scale);
-				default:
-					return this.getMinBeatWidth();
+	public float getDurationWidth(TGDuration duration){
+		float durationWidth = 0f;
+
+		if( this.durationWidths != null ) {
+			int index = 0;
+			for (int value = TGDuration.WHOLE; value <= duration.getValue(); value *= 2) {
+				if (this.durationWidths.length > index) {
+					durationWidth = this.durationWidths[index++];
+				}
 			}
 		}
-		return (20.0f * scale);
+		return durationWidth;
+	}
+	
+	public float getMinimumDurationWidth() {
+		Float minimumWidth = null;
+		if( this.durationWidths != null ) {
+			for (int i = 0; i < this.durationWidths.length; i++) {
+				if (minimumWidth == null || minimumWidth > this.durationWidths[i]) {
+					minimumWidth = this.durationWidths[i];
+				}
+			}
+		}
+		return (minimumWidth != null ? minimumWidth : 0f);
+	}
+	
+	public float getLineWidth(int level) {
+		if( this.lineWidths != null ) {
+			return this.lineWidths[this.lineWidths.length > level ? level : this.lineWidths.length - 1];
+		}
+		return UIPainter.THINNEST_LINE_WIDTH;
 	}
 	
 	public float getScoreNoteWidth() {
@@ -319,142 +333,157 @@ public abstract class TGLayout {
 		return this.playModeEnabled;
 	}
 	
-	public void setMeasureNumberStyle(TGPainter painter){
+	public void setMeasureNumberStyle(UIPainter painter){
 		painter.setFont(getResources().getDefaultFont());
 		painter.setBackground(getLightColor(getResources().getBackgroundColor()));
-		painter.setForeground(getDarkColor(getResources().getColorRed()));
+		painter.setForeground(getDarkColor(getResources().getMeasureNumberColor()));
 	}
 	
-	public void setDivisionsStyle(TGPainter painter, boolean fill){
+	public void setDivisionsStyle(UIPainter painter, boolean fill){
 		painter.setFont(getResources().getDefaultFont());
 		painter.setBackground( (fill ? getResources().getColorBlack() : getLightColor(getResources().getBackgroundColor())));
 		painter.setForeground(getResources().getColorBlack());
 	}
 	
-	public void setTempoStyle(TGPainter painter, boolean fontStyle){
+	public void setTempoStyle(UIPainter painter, boolean fontStyle){
 		painter.setFont(getResources().getDefaultFont());
 		painter.setForeground(getResources().getColorBlack());
 		painter.setBackground( ( fontStyle ? getLightColor(getResources().getBackgroundColor()) : getResources().getColorBlack() ));
 	}
 	
-	public void setTripletFeelStyle(TGPainter painter, boolean fontStyle){
+	public void setTripletFeelStyle(UIPainter painter, boolean fontStyle){
 		painter.setFont(getResources().getDefaultFont());
 		painter.setForeground(getResources().getColorBlack());
 		painter.setBackground( ( fontStyle ? getLightColor(getResources().getBackgroundColor()) : getResources().getColorBlack() ));
 	}
 	
-	public void setMeasurePlayingStyle(TGPainter painter){
+	public void setMeasurePlayingStyle(UIPainter painter){
 		painter.setBackground(getResources().getBackgroundColor());
 		painter.setForeground(getResources().getColorBlack());
 	}
 	
-	public void setLyricStyle(TGPainter painter,boolean playMode){
+	public void setLyricStyle(UIPainter painter,boolean playMode){
 		painter.setFont(getResources().getLyricFont());
 		painter.setBackground(getLightColor(getResources().getBackgroundColor()));
 		painter.setForeground( (playMode ? getResources().getPlayNoteColor() : getResources().getColorBlack()) );
 	}
 	
-	public void setMarkerStyle(TGPainter painter, TGColor color){
+	public void setMarkerStyle(UIPainter painter, UIColor color){
 		painter.setFont(getResources().getMarkerFont());
 		painter.setBackground(getLightColor(getResources().getBackgroundColor()));
 		painter.setForeground(getDarkColor(color));
 	}
 	
-	public void setTextStyle(TGPainter painter){
+	public void setTextStyle(UIPainter painter){
 		painter.setFont(getResources().getTextFont());
 		painter.setBackground(getLightColor(getResources().getBackgroundColor()));
 		painter.setForeground(getResources().getColorBlack());
 	}
 	
-	public void setTimeSignatureStyle(TGPainter painter){
-		painter.setFont(getResources().getTimeSignatureFont());
+	public void setTimeSignatureStyle(UIPainter painter){
 		painter.setForeground(getResources().getColorBlack());
-		painter.setBackground(getLightColor(getResources().getBackgroundColor()));
-	}
-	
-	public void setKeySignatureStyle(TGPainter painter){
 		painter.setBackground(getResources().getColorBlack());
 	}
 	
-	public void setClefStyle(TGPainter painter){
+	public void setKeySignatureStyle(UIPainter painter){
 		painter.setBackground(getResources().getColorBlack());
 	}
 	
-	public void setLineStyle(TGPainter painter){
-		painter.setLineWidth(TGPainter.THINNEST_LINE_WIDTH);
+	public void setClefStyle(UIPainter painter){
+		painter.setBackground(getResources().getColorBlack());
+	}
+	
+	public void setLineStyle(UIPainter painter){
+		painter.setLineWidth(getLineWidth(0));
 		painter.setForeground(getDarkColor( getResources().getLineColor()));
 	}
 	
-	public void setScoreSilenceStyle(TGPainter painter,boolean playMode){
+	public void setScoreSilenceStyle(UIPainter painter,boolean playMode){
 		painter.setForeground( (playMode ? getResources().getPlayNoteColor() : getDarkColor(getResources().getScoreNoteColor())));
 		painter.setBackground( (playMode ? getResources().getPlayNoteColor() : getDarkColor(getResources().getScoreNoteColor())));
 	}
 	
-	public void setTabSilenceStyle(TGPainter painter,boolean playMode){
+	public void setTabSilenceStyle(UIPainter painter,boolean playMode){
 		painter.setForeground( (playMode ? getResources().getPlayNoteColor() : getDarkColor(getResources().getTabNoteColor()) ));
 		painter.setBackground( (playMode ? getResources().getPlayNoteColor() : getDarkColor(getResources().getTabNoteColor()) ));
 	}
 	
-	public void setScoreNoteStyle(TGPainter painter,boolean playing){
+	public void setScoreNoteStyle(UIPainter painter,boolean playing){
 		painter.setForeground( (playing ? getResources().getPlayNoteColor() : getDarkColor(getResources().getScoreNoteColor())));
 		painter.setBackground( (playing ? getResources().getPlayNoteColor() : getDarkColor(getResources().getScoreNoteColor())));
 	}
 	
-	public void setScoreNoteFooterStyle(TGPainter painter){
+	public void setScoreNoteFooterStyle(UIPainter painter){
 		painter.setForeground( getDarkColor(getResources().getScoreNoteColor()) );
 		painter.setBackground( getDarkColor(getResources().getScoreNoteColor()) );
 	}
 	
-	public void setScoreEffectStyle(TGPainter painter){
+	public void setScoreEffectStyle(UIPainter painter){
 		painter.setForeground( getDarkColor(getResources().getScoreNoteColor()) );
 		painter.setBackground( getDarkColor(getResources().getScoreNoteColor()) );
 	}
 	
-	public void setTabNoteStyle(TGPainter painter,boolean playMode){
+	public void setTabNotePathStyle(UIPainter painter,boolean playMode){
+		painter.setForeground((playMode ? getResources().getPlayNoteColor() : getDarkColor(getResources().getTabNoteColor())));
+		painter.setBackground((playMode ? getResources().getPlayNoteColor() : getDarkColor(getResources().getTabNoteColor())));
+	}
+	
+	public void setTabNoteFontStyle(UIPainter painter,boolean playMode){
 		painter.setForeground( (playMode ? getResources().getPlayNoteColor() : getDarkColor(getResources().getTabNoteColor())));
 		painter.setBackground( getLightColor(getResources().getBackgroundColor()) );
 		painter.setFont(getResources().getNoteFont());
 	}
 	
-	public void setTabNoteFooterStyle(TGPainter painter){
-		painter.setForeground( getDarkColor(getResources().getTabNoteColor()));
-		painter.setBackground( getDarkColor(getResources().getTabNoteColor()));
-	}
-
-	public void setTabEffectStyle(TGPainter painter){
+	public void setTabNoteFooterStyle(UIPainter painter){
 		painter.setForeground( getDarkColor(getResources().getTabNoteColor()));
 		painter.setBackground( getDarkColor(getResources().getTabNoteColor()));
 	}
 	
-	public void setTabGraceStyle(TGPainter painter){
+	
+	public void setTiedStyle(UIPainter painter, boolean playing){
+		painter.setForeground( (playing ? getResources().getPlayNoteColor() : getDarkColor(getResources().getScoreNoteColor())));
+		painter.setBackground( (playing ? getResources().getPlayNoteColor() : getDarkColor(getResources().getScoreNoteColor())));
+	}
+	
+	public void setTabTiedStyle(UIPainter painter, boolean playing){
+		painter.setForeground( (playing ? getResources().getPlayNoteColor() : getDarkColor(getResources().getTabNoteColor())));
+		painter.setBackground( (playing ? getResources().getPlayNoteColor() : getDarkColor(getResources().getTabNoteColor())));
+	}
+	
+	public void setTabEffectStyle(UIPainter painter){
+		painter.setForeground( getDarkColor(getResources().getTabNoteColor()));
+		painter.setBackground( getDarkColor(getResources().getTabNoteColor()));
+	}
+	
+	public void setTabGraceStyle(UIPainter painter){
 		painter.setFont(getResources().getGraceFont());
 		painter.setForeground(getDarkColor(getResources().getTabNoteColor()));
 		painter.setBackground(getLightColor(getResources().getBackgroundColor()));
 	}
 	
-	public void setPlayNoteColor(TGPainter painter){
+	public void setPlayNoteColor(UIPainter painter){
 		painter.setForeground(getResources().getPlayNoteColor());
 		painter.setBackground(getResources().getPlayNoteColor());
 	}
 
-	public void setOfflineEffectStyle(TGPainter painter){
+	public void setOfflineEffectStyle(UIPainter painter){
 		painter.setForeground(getDarkColor(((getStyle() & TGLayout.DISPLAY_SCORE) != 0 ? getResources().getScoreNoteColor() : getResources().getTabNoteColor())));
 		painter.setBackground(getLightColor(getResources().getBackgroundColor()));
 		painter.setFont(getResources().getDefaultFont());
 	}
 	
-	public void setDotStyle(TGPainter painter){
-		painter.setForeground(((getStyle() & TGLayout.DISPLAY_SCORE) != 0 ? getResources().getScoreNoteColor() : getResources().getTabNoteColor()));
-		painter.setBackground(((getStyle() & TGLayout.DISPLAY_SCORE) != 0 ? getResources().getScoreNoteColor() : getResources().getTabNoteColor()));
+	public void setDotStyle(UIPainter painter){
+		painter.setForeground(getDarkColor(((getStyle() & TGLayout.DISPLAY_SCORE) != 0 ? getResources().getScoreNoteColor() : getResources().getTabNoteColor())));
+		painter.setBackground(getDarkColor(((getStyle() & TGLayout.DISPLAY_SCORE) != 0 ? getResources().getScoreNoteColor() : getResources().getTabNoteColor())));
 	}
 	
-	public void setDivisionTypeStyle(TGPainter painter){
-		painter.setForeground(getResources().getColorBlack());
+	public void setDivisionTypeStyle(UIPainter painter){
+		painter.setForeground(getDarkColor(((getStyle() & TGLayout.DISPLAY_SCORE) != 0 ? getResources().getScoreNoteColor() : getResources().getTabNoteColor())));
 		painter.setBackground(getLightColor(getResources().getBackgroundColor()));
 		painter.setFont(getResources().getDefaultFont());
 	}
 	
-	public void setRepeatEndingStyle(TGPainter painter){
+	public void setRepeatEndingStyle(UIPainter painter){
 		painter.setForeground(getResources().getColorBlack());
 		painter.setBackground(getLightColor(getResources().getBackgroundColor()));
 		painter.setFont(getResources().getDefaultFont());
@@ -463,7 +492,7 @@ public abstract class TGLayout {
 	public void setChordStyle(TGChordImpl chord){
 		chord.setFont(getResources().getChordFont());
 		chord.setForegroundColor(getResources().getColorBlack());
-		chord.setBackgroundColor(getResources().getBackgroundColor());
+		chord.setBackgroundColor(getLightColor(getResources().getBackgroundColor()));
 		chord.setColor(getDarkColor(getResources().getLineColor()));
 		chord.setNoteColor(getDarkColor(getResources().getTabNoteColor()));
 		chord.setTonicColor(getDarkColor(getResources().getTabNoteColor()));
@@ -476,46 +505,22 @@ public abstract class TGLayout {
 		chord.setFirstFretFont(getResources().getChordFretFont());
 	}
 	
-	public void setLoopSMarkerStyle(TGPainter painter){
+	public void setLoopSMarkerStyle(UIPainter painter){
 		painter.setBackground(getResources().getLoopSMarkerColor());
 	}
 	
-	public void setLoopEMarkerStyle(TGPainter painter){
+	public void setLoopEMarkerStyle(UIPainter painter){
 		painter.setBackground(getResources().getLoopEMarkerColor());
 	}
 	
-	public TGColor getDarkColor(TGColor color) {
+	public UIColor getDarkColor(UIColor color) {
 		return ((this.getStyle() & TGLayout.DISPLAY_MODE_BLACK_WHITE) != 0 ? getResources().getColorBlack() : color );
 	}
 	
-	public TGColor getLightColor(TGColor color) {
+	public UIColor getLightColor(UIColor color) {
 		return ((this.getStyle() & TGLayout.DISPLAY_MODE_BLACK_WHITE) != 0 ? getResources().getColorWhite() : color );
 	}
 	
-	public TGRectangle getNoteOrientation(TGPainter painter, float x, float y, TGNote note){
-		String noteAsString = null;
-		if (note.isTiedNote()){
-			noteAsString = "L";
-			noteAsString = (note.getEffect().isGhostNote())?"(" + noteAsString + ")":noteAsString;
-		}else if(note.getEffect().isDeadNote()){
-			noteAsString = "X";
-			noteAsString = (note.getEffect().isGhostNote())?"(" + noteAsString + ")":noteAsString;
-		}else{
-			noteAsString = Integer.toString(note.getValue());
-			noteAsString = (note.getEffect().isGhostNote())?"(" + noteAsString + ")":noteAsString;
-		}
-		return getOrientation(painter, x, y, noteAsString);
-	}
-	
-	public TGRectangle getOrientation(TGPainter painter, float x, float y, String s){
-		float fmWidth = painter.getFMWidth(s);
-		float fmTopLine = painter.getFMTopLine();
-		float fmMiddleLine = painter.getFMMiddleLine();
-		float fmBaseLine = painter.getFMBaseLine();
-		
-		return new TGRectangle((x - (fmWidth / 2f)), (y + fmMiddleLine), fmWidth, (fmBaseLine - fmTopLine));
-	}
-	
 	public TGSongManager getSongManager() {
 		return getComponent().getSongManager();
 	}
@@ -556,186 +561,126 @@ public abstract class TGLayout {
 		return this.style;
 	}
 	
-	public void setStyle(int style){
+	public void setStyle(int style) {
 		this.style = style;
 	}
-	
+
 	public float getScale() {
 		return this.scale;
 	}
 	
-	public void setScale(float scale) {
-		this.scale = scale;
-	}
-	
 	public float getFontScale() {
 		return this.fontScale;
 	}
 	
-	public void setFontScale(float fontScale) {
-		this.fontScale = fontScale;
-	}
-	
 	public boolean isBufferEnabled() {
 		return this.bufferEnabled;
 	}
 	
-	public void setBufferEnabled(boolean bufferEnabled) {
-		this.bufferEnabled = bufferEnabled;
+	public boolean isTabNotePathRendererEnabled() {
+		return tabNotePathRendererEnabled;
 	}
-	
+
 	public float getFirstMeasureSpacing() {
 		return this.firstMeasureSpacing;
 	}
 	
-	public void setFirstMeasureSpacing(float firstMeasureSpacing) {
-		this.firstMeasureSpacing = firstMeasureSpacing;
+	public float getFirstNoteSpacing() {
+		return firstNoteSpacing;
 	}
-	
+
+	public float getMeasureLeftSpacing() {
+		return measureLeftSpacing;
+	}
+
+	public float getMeasureRightSpacing() {
+		return measureRightSpacing;
+	}
+
+	public float getClefSpacing() {
+		return clefSpacing;
+	}
+
+	public float getKeySignatureSpacing() {
+		return keySignatureSpacing;
+	}
+
+	public float getTimeSignatureSpacing() {
+		return timeSignatureSpacing;
+	}
+
 	public float getMinBufferSeparator() {
 		return this.minBufferSeparator;
 	}
 	
-	public void setMinBufferSeparator(float minBufferSeparator) {
-		this.minBufferSeparator = minBufferSeparator;
-	}
-	
 	public float getMinTopSpacing() {
 		return this.minTopSpacing;
 	}
 	
-	public void setMinTopSpacing(float minTopSpacing) {
-		this.minTopSpacing = minTopSpacing;
-	}
-	
 	public float getMinScoreTabSpacing() {
 		return this.minScoreTabSpacing;
 	}
 	
-	public void setMinScoreTabSpacing(float minScoreTabSpacing) {
-		this.minScoreTabSpacing = minScoreTabSpacing;
-	}
-	
 	public float getScoreLineSpacing() {
 		return this.scoreLineSpacing;
 	}
 	
-	public void setScoreLineSpacing(float scoreLineSpacing) {
-		this.scoreLineSpacing = scoreLineSpacing;
-	}
-	
 	public float getFirstTrackSpacing() {
 		return this.firstTrackSpacing;
 	}
 	
-	public void setFirstTrackSpacing(float firstTrackSpacing) {
-		this.firstTrackSpacing = firstTrackSpacing;
-	}
-	
 	public float getTrackSpacing() {
 		return this.trackSpacing;
 	}
 	
-	public void setTrackSpacing(float trackSpacing) {
-		this.trackSpacing = trackSpacing;
-	}
-	
 	public float getStringSpacing() {
 		return this.stringSpacing;
 	}
 	
-	public void setStringSpacing(float stringSpacing) {
-		this.stringSpacing = stringSpacing;
-	}
-	
 	public float getChordFretIndexSpacing() {
 		return this.chordFretIndexSpacing;
 	}
 	
-	public void setChordFretIndexSpacing(float chordFretIndexSpacing) {
-		this.chordFretIndexSpacing = chordFretIndexSpacing;
-	}
-	
 	public float getChordStringSpacing() {
 		return this.chordStringSpacing;
 	}
 	
-	public void setChordStringSpacing(float chordStringSpacing) {
-		this.chordStringSpacing = chordStringSpacing;
-	}
-	
 	public float getChordFretSpacing() {
 		return this.chordFretSpacing;
 	}
 	
-	public void setChordFretSpacing(float chordFretSpacing) {
-		this.chordFretSpacing = chordFretSpacing;
-	}
-	
 	public float getChordNoteSize() {
 		return this.chordNoteSize;
 	}
 	
-	public void setChordNoteSize(float chordNoteSize) {
-		this.chordNoteSize = chordNoteSize;
-	}
-	
 	public float getChordLineWidth() {
 		return chordLineWidth;
 	}
 
-	public void setChordLineWidth(float chordLineWidth) {
-		this.chordLineWidth = chordLineWidth;
-	}
-
 	public float getRepeatEndingSpacing() {
 		return this.repeatEndingSpacing;
 	}
 	
-	public void setRepeatEndingSpacing(float repeatEndingSpacing) {
-		this.repeatEndingSpacing = repeatEndingSpacing;
-	}
-	
 	public float getDivisionTypeSpacing() {
 		return this.divisionTypeSpacing;
 	}
 	
-	public void setDivisionTypeSpacing(float divisionTypeSpacing) {
-		this.divisionTypeSpacing = divisionTypeSpacing;
-	}
-	
 	public float getTextSpacing() {
 		return this.textSpacing;
 	}
 	
-	public void setTextSpacing(float textSpacing) {
-		this.textSpacing = textSpacing;
-	}
-	
 	public float getMarkerSpacing() {
 		return this.markerSpacing;
 	}
 	
-	public void setMarkerSpacing(float markerSpacing) {
-		this.markerSpacing = markerSpacing;
-	}
-	
 	public float getLoopMarkerSpacing() {
 		return this.loopMarkerSpacing;
 	}
 	
-	public void setLoopMarkerSpacing(float loopMarkerSpacing) {
-		this.loopMarkerSpacing = loopMarkerSpacing;
-	}
-	
 	public float getEffectSpacing() {
 		return this.effectSpacing;
 	}
 	
-	public void setEffectSpacing(float effectSpacing) {
-		this.effectSpacing = effectSpacing;
-	}
-	
 	public float getDefaultChordSpacing(){
 		float spacing = 0;
 		if( (this.style & DISPLAY_CHORD_DIAGRAM) != 0 ){
