@@ -10,10 +10,9 @@ import java.util.ArrayList;
 import java.util.Iterator;
 import java.util.List;
 
-import org.herac.tuxguitar.graphics.TGColor;
-import org.herac.tuxguitar.graphics.TGPainter;
 import org.herac.tuxguitar.graphics.control.painters.TGClefPainter;
 import org.herac.tuxguitar.graphics.control.painters.TGKeySignaturePainter;
+import org.herac.tuxguitar.graphics.control.painters.TGNumberPainter;
 import org.herac.tuxguitar.graphics.control.painters.TGTempoPainter;
 import org.herac.tuxguitar.graphics.control.painters.TGTripletFeelPainter;
 import org.herac.tuxguitar.song.managers.TGSongManager;
@@ -25,6 +24,9 @@ import org.herac.tuxguitar.song.models.TGMarker;
 import org.herac.tuxguitar.song.models.TGMeasure;
 import org.herac.tuxguitar.song.models.TGMeasureHeader;
 import org.herac.tuxguitar.song.models.TGNote;
+import org.herac.tuxguitar.ui.resource.UIColor;
+import org.herac.tuxguitar.ui.resource.UIPainter;
+import org.herac.tuxguitar.ui.resource.UIResourceFactory;
 
 /**
  * @author julian
@@ -81,11 +83,8 @@ public class TGMeasureImpl extends TGMeasure{
 	/**
 	 * Espacio por defecto de la clave
 	 */
-	private static final int DEFAULT_CLEF_SPACING = 40;
-	/**
-	 * Espacio por defecto entre negra y negra
-	 */
-	private static final int DEFAULT_QUARTER_SPACING = 30;
+	private static final int DEFAULT_CLEF_WIDTH = 16;
+	
 	/**
 	 * Posicion X
 	 */
@@ -151,7 +150,8 @@ public class TGMeasureImpl extends TGMeasure{
 	private float beatEffectSpacing;
 	private boolean text;
 	private boolean chord;
-	private boolean division;
+	private boolean division1;
+	private boolean division2;
 	
 	private boolean[][] registeredAccidentals;
 	
@@ -320,8 +320,8 @@ public class TGMeasureImpl extends TGMeasure{
 			}
 		}
 		
-		if(!this.compactMode){
-			this.quarterSpacing = (minDuration != null)?layout.getSpacingForQuarter(minDuration): Math.round(DEFAULT_QUARTER_SPACING * layout.getScale());
+		if(!this.compactMode) {
+			this.quarterSpacing = (minDuration != null ? layout.getSpacingForQuarter(minDuration): layout.getMinimumDurationWidth());
 			if(chordEnabled && minimumChordLength > 0){
 				float chordWidth = (layout.getChordFretIndexSpacing() + layout.getChordStringSpacing() + (((float)getTrack().stringCount()) * layout.getChordStringSpacing()));
 				float minimumSpacing = ((((float)TGDuration.QUARTER_TIME) * chordWidth) / ((float)minimumChordLength));
@@ -352,7 +352,7 @@ public class TGMeasureImpl extends TGMeasure{
 	}
 	
 	private void makeVoice(TGLayout layout,TGVoiceImpl voice,TGVoiceImpl previousVoice,TGBeatGroup group){
-		voice.setWidth(layout.getVoiceWidth(voice));
+		voice.setWidth(layout.getDurationWidth(voice.getDuration()));
 		voice.setBeatGroup( group );
 		
 		if(previousVoice != null){
@@ -404,7 +404,7 @@ public class TGMeasureImpl extends TGMeasure{
 		if((layout.getStyle() & TGLayout.DISPLAY_SCORE) != 0 ){
 			if(this.prevMeasure == null || getClef() != this.prevMeasure.getClef()){
 				this.paintClef = true;
-				this.getHeaderImpl().notifyClefSpacing( Math.round(DEFAULT_CLEF_SPACING * layout.getScale()) );
+				this.getHeaderImpl().notifyClefSpacing(calculateClefSpacing(layout));
 			}
 			if(this.prevMeasure == null || getKeySignature() != this.prevMeasure.getKeySignature()){
 				this.paintKeySignature = true;
@@ -483,8 +483,11 @@ public class TGMeasureImpl extends TGMeasure{
 					}
 					voice.update(layout);
 					
-					if(!this.division && !voice.getDuration().getDivision().isEqual(TGDivisionType.NORMAL)){
-						this.division = true;
+					if(!this.division1 && (v % 2 == 0) && !voice.getDuration().getDivision().isEqual(TGDivisionType.NORMAL)){
+						this.division1 = true;
+					}
+					if(!this.division2 && (v % 2 == 1) && !voice.getDuration().getDivision().isEqual(TGDivisionType.NORMAL)){
+						this.division2 = true;
 					}
 					if( (layout.getStyle() & TGLayout.DISPLAY_SCORE) == 0 || (voice.isRestVoice() && !voice.isHiddenSilence()) ){
 						if( voice.getMaxY() > this.maxY ){
@@ -577,7 +580,8 @@ public class TGMeasureImpl extends TGMeasure{
 	private void resetSpacing(){
 		this.text = false;
 		this.chord = false;
-		this.division = false;
+		this.division1 = false;
+		this.division2 = false;
 		this.beatEffectSpacing = 0;
 	}
 	
@@ -597,8 +601,11 @@ public class TGMeasureImpl extends TGMeasure{
 		if(this.getHeader().getRepeatAlternative() > 0){
 			ts.setSize(TGTrackSpacing.POSITION_REPEAT_ENDING,layout.getRepeatEndingSpacing());
 		}
-		if(this.division){
-			ts.setSize(TGTrackSpacing.POSITION_DIVISION_TYPE,layout.getDivisionTypeSpacing());
+		if(this.division1){
+			ts.setSize(TGTrackSpacing.POSITION_DIVISION_TYPE_1,layout.getDivisionTypeSpacing());
+		}
+		if(this.division2){
+			ts.setSize(TGTrackSpacing.POSITION_DIVISION_TYPE_2,layout.getDivisionTypeSpacing());
 		}
 		if( this.beatEffectSpacing > 0 ){
 			ts.setSize(TGTrackSpacing.POSITION_EFFECTS, this.beatEffectSpacing );
@@ -609,7 +616,7 @@ public class TGMeasureImpl extends TGMeasure{
 		manager.getMeasureManager().orderBeats(this);
 	}
 	
-	public void paintMeasure(TGLayout layout,TGPainter painter) {
+	public void paintMeasure(TGLayout layout,UIPainter painter) {
 		if( this.readyToPaint ) {
 			this.setOutOfBounds(false);
 			
@@ -617,11 +624,12 @@ public class TGMeasureImpl extends TGMeasure{
 			TGResourceBuffer resourceBuffer = layout.getResourceBuffer();
 			
 			if(!bufferEnabled || shouldRepaintBuffer(resourceBuffer)){
-				TGPainter bufferPainter = painter;
+				UIPainter bufferPainter = painter;
 				float x = (bufferEnabled ? 0 : getPosX());
 				float y = (bufferEnabled ? 0 : getPosY());
 				if( bufferEnabled ){
-					bufferPainter = getBuffer().createBuffer(resourceBuffer, painter, getWidth(layout) + getSpacing(), getTs().getSize(), layout.getResources().getBackgroundColor());
+					UIResourceFactory factory = layout.getComponent().getResourceFactory();
+					bufferPainter = getBuffer().createBuffer(resourceBuffer, factory, getWidth(layout) + getSpacing(), getTs().getSize(), layout.getResources().getBackgroundColor());
 				}
 				layout.paintLines(getTrackImpl(), getTs(), bufferPainter, x, y, getWidth(layout) + getSpacing());
 				paintTimeSignature(layout, bufferPainter, x, y);
@@ -635,7 +643,7 @@ public class TGMeasureImpl extends TGMeasure{
 			}
 			if( bufferEnabled ){
 				painter.setBackground(layout.getResources().getBackgroundColor());
-				getBuffer().paintBuffer(resourceBuffer, painter, getPosX(), getPosY(), getTs().getPosition(TGTrackSpacing.POSITION_BUFFER_SEPARATOR));
+				getBuffer().paintBuffer(resourceBuffer, painter, getPosX(), getPosY());
 			}
 			
 			this.paintMarker(layout, painter);
@@ -653,7 +661,7 @@ public class TGMeasureImpl extends TGMeasure{
 		return (!isBufferCreated() || getBuffer().isDisposed(resourceBuffer));
 	}
 	
-	public void paintRepeatEnding(TGLayout layout,TGPainter painter){
+	public void paintRepeatEnding(TGLayout layout,UIPainter painter){
 		if(getHeader().getRepeatAlternative() > 0){
 			float scale = layout.getScale();
 			float x1 = (getPosX() + getHeaderImpl().getLeftSpacing(layout) + getFirstNoteSpacing(layout));
@@ -681,18 +689,92 @@ public class TGMeasureImpl extends TGMeasure{
 	/**
 	 * Pinta las notas
 	 */
-	public void paintComponents(TGLayout layout,TGPainter painter, float fromX, float fromY) {
+	public void paintComponents(TGLayout layout,UIPainter painter, float fromX, float fromY) {
+		float x = (fromX + getHeaderImpl().getLeftSpacing(layout));
+		
 		Iterator<TGBeat> it = getBeats().iterator();
-		while(it.hasNext()){
+		while(it.hasNext()) {
 			TGBeatImpl beat = (TGBeatImpl)it.next();
-			beat.paint(layout, painter, fromX + getHeaderImpl().getLeftSpacing(layout) ,fromY);
+			beat.paint(layout, painter, x, fromY);
 		}
+		
+		this.paintDivisionTypes(layout, painter, x, fromY);
+	}
+	
+	public void paintDivisionTypes(TGLayout layout, UIPainter painter, float fromX, float fromY){
+		for(int v = 0; v < TGBeat.MAX_VOICES; v ++) {
+			if((this.division1 && v % 2 == 0) || (this.division2 && v % 2 == 1)) {
+				this.paintDivisionTypes(layout, painter, fromX, fromY, v);
+			}
+		}
+	}
+	
+	public void paintDivisionTypes(TGLayout layout, UIPainter painter, float fromX, float fromY, int voiceIndex){
+		float x1 = 0;
+		float x2 = 0;
+		
+		TGDivisionType divisionType = null;
+		Iterator<TGBeat> it = getBeats().iterator();
+		while(it.hasNext()) {
+			TGBeatImpl beat = (TGBeatImpl)it.next();
+			TGVoiceImpl voice = beat.getVoiceImpl(voiceIndex);				
+			if( !voice.isEmpty() ) {
+				if( divisionType != null && !voice.getDuration().getDivision().isEqual(divisionType) ) {
+					this.paintDivisionType(layout, painter, divisionType, x1, x2, fromY, voiceIndex);
+					
+					divisionType = null;
+				}
+				
+				if(!voice.getDuration().getDivision().isEqual(TGDivisionType.NORMAL)) {
+					x2 = (fromX + beat.getPosX() + beat.getSpacing(layout));
+					if( divisionType == null ) {
+						divisionType = voice.getDuration().getDivision();
+						x1 = x2;
+					}
+				}
+			}
+		}
+		if( divisionType != null ) {
+			this.paintDivisionType(layout, painter, divisionType, x1, x2, fromY, voiceIndex);
+		}
+	}
+	
+	public void paintDivisionType(TGLayout layout, UIPainter painter, TGDivisionType divisionType, float beatX1, float beatX2, float fromY, int voice) {
+		layout.setDivisionTypeStyle(painter);
+		
+		String label = Integer.toString(divisionType.getEnters());
+		float scale = layout.getScale();
+		float labelWidth = painter.getFMWidth(label);
+		float y = (fromY + getTs().getPosition(voice % 2 == 0 ? TGTrackSpacing.POSITION_DIVISION_TYPE_1 : TGTrackSpacing.POSITION_DIVISION_TYPE_2));
+		float yMove = ((layout.getDivisionTypeSpacing() / 2f) - scale);
+		float xMove = ((((layout.getStyle() & TGLayout.DISPLAY_SCORE) != 0 ? layout.getScoreNoteWidth() : layout.getStringSpacing()) / 2f) + scale);
+		float y1 = (y + yMove + (yMove * (voice % 2 == 0 ? 1 : -1)));
+		float y2 = (y + yMove);
+		float x1 = (beatX1 - xMove);
+		float x2 = (beatX2 + (xMove * 2f));
+		float xCenter = (x1 + ((x2 - x1) / 2f));
+		
+		if( beatX2 > beatX1 ) {
+			painter.setLineWidth(layout.getLineWidth(1));
+			painter.initPath(UIPainter.PATH_DRAW);
+			painter.moveTo(x1, y1);
+			painter.lineTo(x1, y2);
+			painter.lineTo(xCenter - (labelWidth / 2f) - scale, y2);
+			
+			painter.moveTo(x2, y1);
+			painter.lineTo(x2, y2);
+			painter.lineTo(xCenter + (labelWidth / 2f) + scale, y2);
+			
+			painter.closePath();
+		}
+		
+		painter.drawString(label, (xCenter - (labelWidth / 2f)), (y2 + painter.getFMMiddleLine()));
 	}
 	
 	/**
 	 * Pinta las divisiones del compas
 	 */
-	private void paintDivisions(TGLayout layout,TGPainter painter) {
+	private void paintDivisions(TGLayout layout,UIPainter painter) {
 		float x1 = getPosX();
 		float x2 = getPosX() + getWidth(layout);
 		float y1 = 0;
@@ -713,57 +795,61 @@ public class TGMeasureImpl extends TGMeasure{
 		//-----TABLATURE ------------------------------------//
 		if( (style & TGLayout.DISPLAY_TABLATURE) != 0 ){
 			y1 = getPosY() + getTs().getPosition(TGTrackSpacing.POSITION_TABLATURE);
-			y2 = y1 + ((getTrack().getStrings().size() - 1 ) * layout.getStringSpacing());
+			y2 = y1 + (getTrack().stringCount() > 1 ? ((getTrack().stringCount() - 1 ) * layout.getStringSpacing()) : 0f);
+			if( y1 == y2 ) {
+				y1 -= layout.getStringSpacing();
+				y2 += layout.getStringSpacing();
+			}
 			addInfo = ( (style & TGLayout.DISPLAY_SCORE) == 0 );
 			offsetY = 0;
 			paintDivisions(layout, painter, x1, y1, x2, y2, offsetY, addInfo );
 		}
 	}
 	
-	private void paintDivisions(TGLayout layout,TGPainter painter,float x1, float y1, float x2, float y2, float offsetY, boolean addInfo) {
+	private void paintDivisions(TGLayout layout,UIPainter painter,float x1, float y1, float x2, float y2, float offsetY, boolean addInfo) {
 		float scale = layout.getScale();
-		float lineWidthSmall = (1f * scale);
-		float lineWidthBig = Math.max(lineWidthSmall,Math.round(3f * scale));
+		float lineWidthSmall = layout.getLineWidth(1);
+		float lineWidthBig = layout.getLineWidth(3);
 		
 		//numero de compas
 		if( addInfo ){ 
 			String number = Integer.toString(this.getNumber());
 			layout.setMeasureNumberStyle(painter);
-			painter.drawString(number, getPosX() + scale, y1 + painter.getFMBaseLine() - (2f * scale), true);
+			painter.drawString(number, getPosX() + scale, y1 + painter.getFMBaseLine() - (2f * scale));
 		}
 		
-		layout.setDivisionsStyle(painter,true);
+		layout.setDivisionsStyle(painter, true);
 		
 		//principio
 		if( this.isRepeatOpen() || layout.isFirstMeasure(this) ){
-			painter.setLineWidth(TGPainter.THINNEST_LINE_WIDTH);
-			painter.initPath(TGPainter.PATH_DRAW | TGPainter.PATH_FILL);
+			painter.setLineWidth(layout.getLineWidth(0));
+			painter.initPath(UIPainter.PATH_DRAW | UIPainter.PATH_FILL);
 			painter.setAntialias(false);
 			painter.addRectangle(x1, y1, lineWidthBig, (y2 + offsetY) - y1);
 			painter.closePath();
 			
-			painter.setLineWidth(TGPainter.THINNEST_LINE_WIDTH);
-			painter.initPath(TGPainter.PATH_DRAW | TGPainter.PATH_FILL);
+			painter.setLineWidth(layout.getLineWidth(0));
+			painter.initPath(UIPainter.PATH_DRAW | UIPainter.PATH_FILL);
 			painter.setAntialias(false);
 			painter.addRectangle(x1 + lineWidthBig + (2f * scale), y1, lineWidthSmall, (y2 + offsetY) - y1);
 			painter.closePath();
 			
 			if( this.isRepeatOpen() ){
-				int size = Math.max(1,Math.round(4f * scale));
-				float xMove = ((lineWidthBig + scale + lineWidthSmall) + (2f * scale));
-				float yMove = ((lineWidthBig + scale + lineWidthSmall) + (2f * scale));
+				float size = layout.getLineWidth(4);
+				float xMove = (((lineWidthBig + scale + lineWidthSmall) + (2f * scale)) + size);
+				float yMove = size;
 				
 				painter.setLineWidth(lineWidthSmall);
-				painter.initPath(TGPainter.PATH_FILL);
-				painter.moveTo(x1 + xMove, y1 + ((y2 - y1) / 2) - (yMove + (size / 2)));
-				painter.addOval(x1 + xMove, y1 + ((y2 - y1) / 2) - (yMove + (size / 2)), size,size);
-				painter.moveTo(x1 + xMove, y1 + ((y2 - y1) / 2) + (yMove - (size / 2)));
-				painter.addOval(x1 + xMove, y1 + ((y2 - y1) / 2) + (yMove - (size / 2)), size, size);
+				painter.initPath(UIPainter.PATH_FILL);
+				painter.moveTo(x1 + xMove, y1 + ((y2 - y1) / 2f) - yMove);
+				painter.addCircle(x1 + xMove, y1 + ((y2 - y1) / 2f) - yMove, size);
+				painter.moveTo(x1 + xMove, y1 + ((y2 - y1) / 2f) + yMove);
+				painter.addCircle(x1 + xMove, y1 + ((y2 - y1) / 2f) + yMove, size);
 				painter.closePath();
 			}
 		} else {
-			painter.setLineWidth(TGPainter.THINNEST_LINE_WIDTH);
-			painter.initPath(TGPainter.PATH_DRAW | TGPainter.PATH_FILL);
+			painter.setLineWidth(layout.getLineWidth(0));
+			painter.initPath(UIPainter.PATH_DRAW | UIPainter.PATH_FILL);
 			painter.setAntialias(false);
 			painter.moveTo(x1, y1);
 			painter.lineTo(x1, (y2 + offsetY));
@@ -772,40 +858,40 @@ public class TGMeasureImpl extends TGMeasure{
 		
 		//fin
 		if( this.getRepeatClose() > 0 || layout.isLastMeasure(this) ){
-			painter.setLineWidth(TGPainter.THINNEST_LINE_WIDTH);
-			painter.initPath(TGPainter.PATH_DRAW | TGPainter.PATH_FILL);
+			painter.setLineWidth(layout.getLineWidth(0));
+			painter.initPath(UIPainter.PATH_DRAW | UIPainter.PATH_FILL);
 			painter.setAntialias(false);
 			painter.addRectangle((x2 + getSpacing()) - (lineWidthBig + lineWidthSmall + (2f * scale)), y1, lineWidthSmall, (y2 - y1));
 			painter.closePath();
 			
-			painter.setLineWidth(TGPainter.THINNEST_LINE_WIDTH);
-			painter.initPath(TGPainter.PATH_DRAW | TGPainter.PATH_FILL);
+			painter.setLineWidth(layout.getLineWidth(0));
+			painter.initPath(UIPainter.PATH_DRAW | UIPainter.PATH_FILL);
 			painter.setAntialias(false);
 			painter.addRectangle((x2 + getSpacing()) - lineWidthBig, y1, lineWidthBig, (y2 - y1));
 			painter.closePath();
 			
 			if( this.getRepeatClose() > 0 ){
-				int size = Math.max(1,Math.round(4f * scale));
+				float size = layout.getLineWidth(4);
 				float xMove = (((lineWidthBig + scale + lineWidthSmall) + (2f * scale)) + size);
-				float yMove = ( (lineWidthBig + scale + lineWidthSmall) + (2f * scale) );
+				float yMove = size;
 				
 				painter.setLineWidth(lineWidthSmall);
-				painter.initPath(TGPainter.PATH_FILL);
-				painter.moveTo((x2 - xMove) + getSpacing(), y1 + ((y2 - y1) / 2) - (yMove + (size / 2)));
-				painter.addOval((x2 - xMove) + getSpacing(), y1 + ((y2 - y1) / 2) - (yMove + (size / 2)), size,size);
-				painter.moveTo((x2 - xMove) + getSpacing(), y1 + ((y2 - y1) / 2) + (yMove - (size / 2)));
-				painter.addOval((x2 - xMove) + getSpacing(), y1 + ((y2 - y1) / 2) + (yMove - (size / 2)), size, size);
+				painter.initPath(UIPainter.PATH_FILL);
+				painter.moveTo((x2 - xMove) + getSpacing(), y1 + ((y2 - y1) / 2f) - yMove);
+				painter.addCircle((x2 - xMove) + getSpacing(), y1 + ((y2 - y1) / 2f) - yMove, size);
+				painter.moveTo((x2 - xMove) + getSpacing(), y1 + ((y2 - y1) / 2f) + yMove);
+				painter.addCircle((x2 - xMove) + getSpacing(), y1 + ((y2 - y1) / 2f) + yMove, size);
 				painter.closePath();
 				if( addInfo ){
 					layout.setDivisionsStyle(painter,false);
 					
 					String repetitions = ("x" + this.getRepeatClose());
-					painter.drawString(repetitions, x2 - painter.getFMWidth(repetitions) + getSpacing() - size, y1 + painter.getFMBaseLine() - (2f * scale), true);
+					painter.drawString(repetitions, x2 - painter.getFMWidth(repetitions) + getSpacing() - size, y1 + painter.getFMBaseLine() - (2f * scale));
 				}
 			}
 		} else {
-			painter.setLineWidth(TGPainter.THINNEST_LINE_WIDTH);
-			painter.initPath(TGPainter.PATH_DRAW | TGPainter.PATH_FILL);
+			painter.setLineWidth(layout.getLineWidth(0));
+			painter.initPath(UIPainter.PATH_DRAW | UIPainter.PATH_FILL);
 			painter.setAntialias(false);
 			painter.moveTo((x2 + getSpacing()), y1);
 			painter.lineTo((x2 + getSpacing()), y2);
@@ -818,13 +904,13 @@ public class TGMeasureImpl extends TGMeasure{
 	/**
 	 * Pinta la Clave
 	 */
-	private void paintClef(TGLayout layout,TGPainter painter,float fromX, float fromY) {
+	private void paintClef(TGLayout layout,UIPainter painter,float fromX, float fromY) {
 		//-----SCORE ------------------------------------//
 		if((layout.getStyle() & TGLayout.DISPLAY_SCORE) != 0 && this.paintClef){
-			float x = fromX + Math.round( 14 * layout.getScale() ) ;
-			float y = fromY + getTs().getPosition(TGTrackSpacing.POSITION_SCORE_MIDDLE_LINES);
+			float x = (fromX + getHeaderImpl().getLeftSpacing(layout));
+			float y = (fromY + getTs().getPosition(TGTrackSpacing.POSITION_SCORE_MIDDLE_LINES));
 			layout.setClefStyle(painter);
-			painter.initPath(TGPainter.PATH_FILL);
+			painter.initPath(UIPainter.PATH_FILL);
 			if(this.getClef() == TGMeasure.CLEF_TREBLE){
 				TGClefPainter.paintTreble(painter, x, y,layout.getScoreLineSpacing());
 			}
@@ -844,11 +930,11 @@ public class TGMeasureImpl extends TGMeasure{
 	/**
 	 * Pinta la Armadura de Clave
 	 */
-	private void paintKeySignature(TGLayout layout,TGPainter painter, float fromX, float fromY) {
+	private void paintKeySignature(TGLayout layout,UIPainter painter, float fromX, float fromY) {
 		if((layout.getStyle() & TGLayout.DISPLAY_SCORE) != 0 && this.paintKeySignature){
 			float scale = layout.getScoreLineSpacing();
-			float x = fromX + getClefSpacing(layout) + 10;
-			float y = fromY + getTs().getPosition(TGTrackSpacing.POSITION_SCORE_MIDDLE_LINES);
+			float x = (fromX + getHeaderImpl().getLeftSpacing(layout) + getClefSpacing(layout));
+			float y = (fromY + getTs().getPosition(TGTrackSpacing.POSITION_SCORE_MIDDLE_LINES));
 			int clefIndex = (this.getClef() - 1);
 			int currentKey = this.getKeySignature();
 			int previousKey = (this.prevMeasure != null ? this.prevMeasure.getKeySignature() : 0);
@@ -860,7 +946,7 @@ public class TGMeasureImpl extends TGMeasure{
 				int naturalFrom =  (currentKey >= 1 && currentKey <= 7) ? currentKey : 0;
 				for(int i = naturalFrom; i < previousKey; i ++ ){
 					float offset =  ( ( (scale / 2) * SCORE_KEY_SHARP_POSITIONS[clefIndex][i] )  - (scale / 2) );
-					painter.initPath(TGPainter.PATH_FILL);
+					painter.initPath(UIPainter.PATH_FILL);
 					TGKeySignaturePainter.paintNatural(painter,x, (y +  offset  ), scale);
 					painter.closePath();
 					x += (scale - (scale / 4));
@@ -870,7 +956,7 @@ public class TGMeasureImpl extends TGMeasure{
 				int naturalFrom =  (currentKey >= 8 && currentKey <= 14) ? currentKey : 7;
 				for(int i = naturalFrom; i < previousKey; i ++ ){
 					float offset =  ( ( (scale / 2) * SCORE_KEY_FLAT_POSITIONS[clefIndex][i - 7] )  - (scale / 2) );
-					painter.initPath(TGPainter.PATH_FILL);
+					painter.initPath(UIPainter.PATH_FILL);
 					TGKeySignaturePainter.paintNatural(painter,x, (y +  offset  ), scale);
 					painter.closePath();
 					x += (scale - (scale / 4));
@@ -881,7 +967,7 @@ public class TGMeasureImpl extends TGMeasure{
 			if(currentKey >= 1 && currentKey <= 7){
 				for(int i = 0; i < currentKey; i ++ ){
 					float offset =  ( ( (scale / 2) * SCORE_KEY_SHARP_POSITIONS[clefIndex][i] )  - (scale / 2) );
-					painter.initPath(TGPainter.PATH_FILL);
+					painter.initPath(UIPainter.PATH_FILL);
 					TGKeySignaturePainter.paintSharp(painter,x, (y +  offset  ), scale);
 					painter.closePath();
 					x += (scale - (scale / 4));
@@ -891,7 +977,7 @@ public class TGMeasureImpl extends TGMeasure{
 			else if(currentKey >= 8 && currentKey <= 14){
 				for(int i = 7; i < currentKey; i ++ ){
 					float offset =  ( ( (scale / 2) * SCORE_KEY_FLAT_POSITIONS[clefIndex][i - 7] )  - (scale / 2) );
-					painter.initPath(TGPainter.PATH_FILL);
+					painter.initPath(UIPainter.PATH_FILL);
 					TGKeySignaturePainter.paintFlat(painter,x, (y +  offset  ), scale);
 					painter.closePath();
 					x += (scale - (scale / 4));
@@ -900,37 +986,45 @@ public class TGMeasureImpl extends TGMeasure{
 		}
 	}
 	
-	private void paintTimeSignature(TGLayout layout,TGPainter painter, float fromX, float fromY){
+	private void paintTimeSignature(TGLayout layout,UIPainter painter, float fromX, float fromY){
 		if(this.getHeaderImpl().shouldPaintTimeSignature()){
-			layout.setTimeSignatureStyle(painter);
 			int style = layout.getStyle();
-			float scale = layout.getScale();
-			float leftSpacing = Math.round( 5.0f * scale );
-			float fmTopLine = painter.getFMTopLine();
-			float fmBaseLine = painter.getFMBaseLine();
-			
-			float x = (getClefSpacing(layout) + getKeySignatureSpacing(layout) + getHeaderImpl().getLeftSpacing(layout) + leftSpacing);
-			String numerator = Integer.toString(getTimeSignature().getNumerator());
-			String denominator = Integer.toString(getTimeSignature().getDenominator().getValue());
-			if( (style & TGLayout.DISPLAY_SCORE) != 0 ){
-				float y = getTs().getPosition(TGTrackSpacing.POSITION_SCORE_MIDDLE_LINES);
-				float y1 = (y + fmTopLine + (1f * scale));
-				float y2 = ((y + getTrackImpl().getScoreHeight()) + fmBaseLine - (1f * scale));
-				
-				painter.drawString(numerator,fromX + x,fromY + y1,true);
-				painter.drawString(denominator,fromX + x,fromY + y2,true);
-			}else if( (style & TGLayout.DISPLAY_TABLATURE) != 0 ){
-				float y = getTs().getPosition(TGTrackSpacing.POSITION_TABLATURE);
-				float y1 = (y + fmTopLine + (1f * scale));
-				float y2 = ((y + getTrackImpl().getTabHeight()) + fmBaseLine - (1f * scale));
-				
-				painter.drawString(numerator,fromX + x,fromY + y1,true);
-				painter.drawString(denominator,fromX + x,fromY + y2,true);
+			float x = (fromX + getHeaderImpl().getLeftSpacing(layout) + getClefSpacing(layout) + getKeySignatureSpacing(layout));
+			float y = 0f;
+			float y1 = 0f;
+			float y2 = 0f;
+			float height = 0;
+			if((style & TGLayout.DISPLAY_SCORE) != 0 ) {
+				y = getTs().getPosition(TGTrackSpacing.POSITION_SCORE_MIDDLE_LINES);
+				y1 = y;
+				y2 = (y + getTrackImpl().getScoreHeight());
+				height = ((layout.getScoreLineSpacing() * 2f) - layout.getScale());
+			} else if((style & TGLayout.DISPLAY_TABLATURE) != 0 ) {
+				y = getTs().getPosition(TGTrackSpacing.POSITION_TABLATURE);
+				y1 = y;
+				y2 = (y + getTrackImpl().getTabHeight());
+				height = ((layout.getStringSpacing() * 3f) / 2f);
 			}
+			
+			if((y2 - y1) < (height * 2f)) {
+				float yMove = ((((height * 2f) - (y2 - y1)) / 2f));
+				
+				y1 -= yMove;
+				y2 += yMove;
+			}
+			
+			float w1 = TGNumberPainter.getDigitsWidth(getTimeSignature().getNumerator(), height);
+			float w2 = TGNumberPainter.getDigitsWidth(getTimeSignature().getDenominator().getValue(), height);
+			float wMove1 = (w2 > w1 ? (w2 - w1) / 2f : 0f);
+			float wMove2 = (w1 > w2 ? (w1 - w2) / 2f : 0f);
+			
+			layout.setTimeSignatureStyle(painter);
+			TGNumberPainter.paintDigits(getTimeSignature().getNumerator(), painter, x + wMove1, fromY + y1, height);
+			TGNumberPainter.paintDigits(getTimeSignature().getDenominator().getValue(), painter, x + wMove2, fromY + y2 - height, height);
 		}
 	}
 	
-	private void paintTempo(TGLayout layout,TGPainter painter){
+	private void paintTempo(TGLayout layout,UIPainter painter){
 		if(this.getHeaderImpl().shouldPaintTempo()){
 			float scale = 5f * layout.getScale(); 
 			float x = (getPosX() + getHeaderImpl().getLeftSpacing(layout));
@@ -938,9 +1032,9 @@ public class TGMeasureImpl extends TGMeasure{
 			float lineSpacing = (Math.max(layout.getScoreLineSpacing() , layout.getStringSpacing()));
 			int style = layout.getStyle();
 			if( (style & TGLayout.DISPLAY_SCORE) != 0 ){
-				y += ( getTs().getPosition(TGTrackSpacing.POSITION_SCORE_MIDDLE_LINES) - lineSpacing ) ;
+				y += ( getTs().getPosition(TGTrackSpacing.POSITION_SCORE_MIDDLE_LINES) - lineSpacing );
 			}else if( (style & TGLayout.DISPLAY_TABLATURE) != 0 ){
-				y += ( getTs().getPosition(TGTrackSpacing.POSITION_TABLATURE) - lineSpacing ) ;
+				y += ( getTs().getPosition(TGTrackSpacing.POSITION_TABLATURE) - (getTrack().stringCount() > 1 ? lineSpacing : (lineSpacing * 2f)));
 			}
 			
 			layout.setTempoStyle(painter, false);
@@ -953,11 +1047,11 @@ public class TGMeasureImpl extends TGMeasure{
 			String value = (" = " + getTempo().getValue());
 			float fontX = x + (Math.round( (1.33f * scale) ) + 1 );
 			float fontY = (y - (0.75f * scale) + painter.getFMBaseLine());
-			painter.drawString(value , fontX, fontY, true);
+			painter.drawString(value , fontX, fontY);
 		}
 	}
 	
-	private void paintTripletFeel(TGLayout layout,TGPainter painter){
+	private void paintTripletFeel(TGLayout layout,UIPainter painter){
 		if(this.getHeaderImpl().shouldPaintTripletFeel()){
 			float scale = (5f * layout.getScale());
 			float x = (getPosX() + getHeaderImpl().getLeftSpacing(layout) + getHeaderImpl().getTempoSpacing(layout));
@@ -967,14 +1061,14 @@ public class TGMeasureImpl extends TGMeasure{
 			if( (style & TGLayout.DISPLAY_SCORE) != 0 ){
 				y += ( getTs().getPosition(TGTrackSpacing.POSITION_SCORE_MIDDLE_LINES) - lineSpacing );
 			}else if( (style & TGLayout.DISPLAY_TABLATURE) != 0 ){
-				y += ( getTs().getPosition(TGTrackSpacing.POSITION_TABLATURE) - lineSpacing );
+				y += ( getTs().getPosition(TGTrackSpacing.POSITION_TABLATURE) - (getTrack().stringCount() > 1 ? lineSpacing : (lineSpacing * 2f)));
 			}
 			
 			layout.setTripletFeelStyle(painter, true);
 			String equal = (" = ");
 			float fontX = (x + (3.2f * scale));
 			float fontY = (y - (0.75f * scale) + painter.getFMBaseLine());
-			painter.drawString(equal, fontX , fontY, true);
+			painter.drawString(equal, fontX , fontY);
 			
 			layout.setTripletFeelStyle(painter, false);
 			float x1 = x;
@@ -1004,7 +1098,7 @@ public class TGMeasureImpl extends TGMeasure{
 		}
 	}
 	
-	private void paintLoopMarker(TGLayout layout,TGPainter painter){
+	private void paintLoopMarker(TGLayout layout,UIPainter painter){
 		if( layout.hasLoopMarker( this ) ){
 			int size = Math.round( layout.getLoopMarkerSpacing() - (1f * layout.getScale()));
 			if( layout.getComponent().isLoopSHeader(this.getHeader())){
@@ -1022,23 +1116,23 @@ public class TGMeasureImpl extends TGMeasure{
 		}
 	}
 	
-	private void paintLoopMarker(TGPainter painter, float x, float y, float size){
-		painter.initPath( TGPainter.PATH_FILL );
+	private void paintLoopMarker(UIPainter painter, float x, float y, float size){
+		painter.initPath( UIPainter.PATH_FILL );
 		painter.addRectangle(x, y, size, size);
 		painter.closePath();
 	}
 	
-	private void paintMarker(TGLayout layout,TGPainter painter){
+	private void paintMarker(TGLayout layout, UIPainter painter){
 		if( this.hasMarker() ){
 			float x = (getPosX() + getHeaderImpl().getLeftSpacing(layout) + getFirstNoteSpacing(layout));
 			float y = (getPosY() + getTs().getPosition(TGTrackSpacing.POSITION_MARKER));
 			
-			layout.setMarkerStyle(painter, getMarkerColor(layout.getResourceBuffer(), painter));
+			layout.setMarkerStyle(painter, getMarkerColor(layout.getResourceBuffer(), layout.getComponent().getResourceFactory()));
 			painter.drawString(getMarker().getTitle(), x, y);
 		}
 	}
 	
-	private void paintTexts(TGLayout layout,TGPainter painter){
+	private void paintTexts(TGLayout layout,UIPainter painter){
 		Iterator<TGBeat> it = getBeats().iterator();
 		while(it.hasNext()){
 			TGBeat beat = (TGBeat)it.next();
@@ -1049,7 +1143,7 @@ public class TGMeasureImpl extends TGMeasure{
 		}
 	}
 	
-	private void paintPlayMode(TGLayout layout,TGPainter painter){
+	public void paintPlayMode(TGLayout layout,UIPainter painter){
 		if(layout.isPlayModeEnabled() && isPlaying(layout)){
 			float scale = layout.getScale();
 			float width = getWidth(layout) + getSpacing();
@@ -1070,7 +1164,7 @@ public class TGMeasureImpl extends TGMeasure{
 			// Don't uncomment "lineStyle" until be sure SWT bug has fixed.
 			// See bug: https://bugs.eclipse.org/bugs/show_bug.cgi?id=225725
 			//painter.setLineStyle(SWT.LINE_DASH);
-			painter.setLineWidth(1f * scale);
+			painter.setLineWidth(layout.getLineWidth(1));
 			painter.initPath();
 			painter.setAntialias(false);
 			painter.addRectangle(getPosX() + (5f * scale),y1,width - (10f * scale),(y2 - y1));
@@ -1091,8 +1185,9 @@ public class TGMeasureImpl extends TGMeasure{
 		float mPadding = (bMargin + getHeaderImpl().getLeftSpacing(layout) + getHeaderImpl().getRightSpacing(layout));
 		float mWidth = (this.getWidth(layout) - mPadding);
 		float mWidthWithSpacing = (mWidth + getSpacing());
-		if( mWidthWithSpacing < layout.getMinBeatWidth() ) {
-			mWidthWithSpacing = layout.getMinBeatWidth();
+		float minimumDurationWidth = layout.getMinimumDurationWidth();
+		if( mWidthWithSpacing < minimumDurationWidth ) {
+			mWidthWithSpacing = minimumDurationWidth;
 		}
 		
 		float beatX = (beat.getPosX() - bMargin);
@@ -1112,21 +1207,28 @@ public class TGMeasureImpl extends TGMeasure{
 		return ((layout.getStyle() & TGLayout.DISPLAY_MULTITRACK) != 0 ?this.getHeaderImpl().getMaxWidth():this.width);
 	}
 	
+	private float calculateClefSpacing(TGLayout layout) {
+		return (Math.round(DEFAULT_CLEF_WIDTH * layout.getScale()) + Math.round(layout.getClefSpacing()));
+	}
+	
 	private float calculateKeySignatureSpacing(TGLayout layout){
 		float spacing = 0;
-		if(this.paintKeySignature){
-			if(this.getKeySignature() <= 7){
+		if( this.paintKeySignature) {
+			if( this.getKeySignature() <= 7){
 				spacing += Math.round( ( 6f * layout.getScale() ) * this.getKeySignature() ) ;
 			}else{
 				spacing += Math.round( ( 6f * layout.getScale() ) * (this.getKeySignature() - 7) ) ;
 			}
-			if(this.prevMeasure != null ){
+			if( this.prevMeasure != null ){
 				if(this.prevMeasure.getKeySignature() <= 7){
 					spacing += Math.round( ( 6f * layout.getScale() ) * this.prevMeasure.getKeySignature() ) ;
 				}else{
 					spacing += Math.round( ( 6f * layout.getScale() ) * (this.prevMeasure.getKeySignature() - 7) ) ;
 				}
 			}
+			if( spacing > 0 ) {
+				spacing += layout.getKeySignatureSpacing();
+			}
 		}
 		return spacing;
 	}
@@ -1292,17 +1394,17 @@ public class TGMeasureImpl extends TGMeasure{
 		return (TGMarker.class.getName() + "-" + this.getHeader().getNumber());
 	}
 	
-	public TGColor getMarkerColor(TGResourceBuffer buffer, TGPainter painter){
+	public UIColor getMarkerColor(TGResourceBuffer buffer, UIResourceFactory factory){
 		String resourceKey = this.getMarkerRegistryKey();
 		TGMarker m = getMarker();
-		TGColor markerColor = buffer.getResource(resourceKey);
+		UIColor markerColor = buffer.getResource(resourceKey);
 		if( markerColor != null && !markerColor.isDisposed() ){
 			if( markerColor.getRed() != m.getColor().getR() || markerColor.getGreen() != m.getColor().getG() || markerColor.getBlue() != m.getColor().getB() ){
 				buffer.disposeResource(resourceKey);
 			}
 		}
 		if( markerColor == null || markerColor.isDisposed() ){
-			markerColor = painter.createColor(m.getColor().getR(), m.getColor().getG(), m.getColor().getB());
+			markerColor = factory.createColor(m.getColor().getR(), m.getColor().getG(), m.getColor().getB());
 			
 			buffer.setResource(resourceKey, markerColor);
 		}
