@@ -2,14 +2,13 @@ package org.herac.tuxguitar.graphics.control;
 
 import java.util.Iterator;
 
-import org.herac.tuxguitar.graphics.TGPainter;
 import org.herac.tuxguitar.graphics.control.painters.TGNotePainter;
 import org.herac.tuxguitar.graphics.control.painters.TGSilencePainter;
 import org.herac.tuxguitar.song.factory.TGFactory;
-import org.herac.tuxguitar.song.models.TGDivisionType;
 import org.herac.tuxguitar.song.models.TGDuration;
 import org.herac.tuxguitar.song.models.TGNote;
 import org.herac.tuxguitar.song.models.TGVoice;
+import org.herac.tuxguitar.ui.resource.UIPainter;
 
 public class TGVoiceImpl extends TGVoice{
 	/**
@@ -262,31 +261,31 @@ public class TGVoiceImpl extends TGVoice{
 			}
 			
 			int duration = getDuration().getValue();
-			if(duration == TGDuration.WHOLE){
+			if( duration == TGDuration.WHOLE) {
 				this.silenceHeight = (scale * 3.6513581f);
-				this.silenceY = ( lineCount <= 5 ? lineSpacing : lineSpacing * 2 );
+				this.silenceY = ((style & TGLayout.DISPLAY_SCORE) != 0 ? lineSpacing : (lineSpacing * (int)((lineCount - 1) / 2)));
 			}
-			else if(duration == TGDuration.HALF){
+			else if(duration == TGDuration.HALF) {
 				this.silenceHeight = (scale * 3.6513581f);
-				this.silenceY = ( lineCount <= 5 ? lineSpacing * 2 : lineSpacing * 3 ) - this.silenceHeight;
+				this.silenceY = (((style & TGLayout.DISPLAY_SCORE) != 0 ? lineSpacing * 2 : (lineSpacing * (int)(lineCount / 2))) - this.silenceHeight);
 			}
-			else if(duration == TGDuration.QUARTER){
+			else if(duration == TGDuration.QUARTER) {
 				this.silenceHeight = (scale * 16);
 				this.silenceY = ((lineSpacing * (lineCount - 1)) / 2) - (this.silenceHeight / 2);
 			}
-			else if(duration == TGDuration.EIGHTH){
+			else if(duration == TGDuration.EIGHTH) {
 				this.silenceHeight = (scale * 12);
 				this.silenceY = ((lineSpacing * (lineCount - 1)) / 2) - (this.silenceHeight / 2);
 			}
-			else if(duration == TGDuration.SIXTEENTH){
+			else if(duration == TGDuration.SIXTEENTH) {
 				this.silenceHeight = (scale * 16);
 				this.silenceY = ((lineSpacing * (lineCount - 1)) / 2) - (this.silenceHeight / 2);
 			}
-			else if(duration == TGDuration.THIRTY_SECOND){
+			else if(duration == TGDuration.THIRTY_SECOND) {
 				this.silenceHeight = (scale * 24);
 				this.silenceY = ((lineSpacing * (lineCount - 1)) / 2) - (this.silenceHeight / 2);
 			}
-			else if(duration == TGDuration.SIXTY_FOURTH){
+			else if(duration == TGDuration.SIXTY_FOURTH) {
 				this.silenceHeight = (scale * 28);
 				this.silenceY = ((lineSpacing * (lineCount - 1)) / 2) - (this.silenceHeight / 2);
 			}
@@ -341,7 +340,7 @@ public class TGVoiceImpl extends TGVoice{
 		}
 	}
 	
-	public void paint(TGLayout layout,TGPainter painter, float fromX, float fromY) {
+	public void paint(TGLayout layout,UIPainter painter, float fromX, float fromY) {
 		if(!isEmpty()){
 			if( isRestVoice() && !isHiddenSilence() ){
 				paintSilence(layout, painter, fromX, fromY);
@@ -360,12 +359,13 @@ public class TGVoiceImpl extends TGVoice{
 	}
 	
 	//----silence
-	public void paintSilence(TGLayout layout,TGPainter painter, float fromX, float fromY) {
+	public void paintSilence(TGLayout layout,UIPainter painter, float fromX, float fromY) {
 		int style = layout.getStyle();
 		float x = 0;
 		float lineSpacing = 0;
 		float y = 0;
 		float scale = 0;
+		float layoutScale = layout.getScale();
 		
 		if((style & TGLayout.DISPLAY_SCORE) != 0 ){
 			x = fromX + getPosX() + getBeatImpl().getSpacing(layout);
@@ -380,7 +380,7 @@ public class TGVoiceImpl extends TGVoice{
 		}
 		
 		setStyle(layout, painter,(layout.isPlayModeEnabled() && isPlaying(layout)));
-		painter.initPath(TGPainter.PATH_FILL);
+		painter.initPath(UIPainter.PATH_FILL);
 		
 		int duration = getDuration().getValue();
 		if(duration == TGDuration.WHOLE){
@@ -407,28 +407,12 @@ public class TGVoiceImpl extends TGVoice{
 		
 		painter.closePath();
 		
-		if(getDuration().isDotted() || getDuration().isDoubleDotted()){
-			layout.setDotStyle(painter);
-			painter.initPath();
-			painter.moveTo(x + 10,y +1);
-			painter.addOval(x + 10,y +1,1,1);
-			if(getDuration().isDoubleDotted()){
-				painter.moveTo(x + 13,y +1);
-				painter.addOval(x + 13,y +1,1,1);
-			}
-			painter.closePath();
-		}
-		if(!getDuration().getDivision().isEqual(TGDivisionType.NORMAL)){
-			layout.setDivisionTypeStyle(painter);
-			if((style & TGLayout.DISPLAY_SCORE) != 0 ){
-				painter.drawString(Integer.toString(getDuration().getDivision().getEnters()), x,(fromY + getPaintPosition(TGTrackSpacing.POSITION_DIVISION_TYPE)));
-			}else{
-				painter.drawString(Integer.toString(getDuration().getDivision().getEnters()),x,(fromY + getPaintPosition(TGTrackSpacing.POSITION_DIVISION_TYPE)));
-			}
+		if( getDuration().isDotted() || getDuration().isDoubleDotted()) {
+			paintDot(layout, painter, (x + 10f * layoutScale), (y + 2f * layoutScale), layoutScale);
 		}
 	}
 	
-	public void setStyle(TGLayout layout, TGPainter painter, boolean playMode){
+	public void setStyle(TGLayout layout, UIPainter painter, boolean playMode){
 		if((layout.getStyle() & TGLayout.DISPLAY_SCORE) != 0 ){
 			layout.setScoreSilenceStyle(painter, playMode);
 		}else{
@@ -436,7 +420,7 @@ public class TGVoiceImpl extends TGVoice{
 		}
 	}
 	
-	public void paintBeat(TGLayout layout,TGPainter painter, float fromX, float fromY){
+	public void paintBeat(TGLayout layout,UIPainter painter, float fromX, float fromY){
 		if(!isRestVoice() ){
 			int style = layout.getStyle();
 			float spacing = getBeatImpl().getSpacing(layout);
@@ -450,16 +434,17 @@ public class TGVoiceImpl extends TGVoice{
 		}
 	}
 	
-	public void paintTablatureBeat(TGLayout layout,TGPainter painter, float fromX, float fromY, float spacing){
+	public void paintTablatureBeat(TGLayout layout,UIPainter painter, float fromX, float fromY, float spacing){
 		if(!isRestVoice() ){
 			float scale = layout.getScale();
 			float xMove = (2f * scale);
 			float x = ( fromX + getPosX() + spacing + xMove );
 			float y1 = 0;
 			float y2 = 0;
-			float verticalLineWidth = scale;
-			float horizontalLineWidth = (2f * scale);
+			float verticalLineWidth = layout.getLineWidth(1);
+			float horizontalLineWidth = layout.getLineWidth(2);
 			float stringSpacing = layout.getStringSpacing();
+			float direction = (getBeatGroup().getDirection() == TGBeatGroup.DIRECTION_DOWN ? 1f : -1f);
 			if( getBeatGroup().getDirection() == TGBeatGroup.DIRECTION_DOWN ){
 				y1 = (fromY + getMeasureImpl().getTrackImpl().getTabHeight() + (stringSpacing / 2));
 				y2 = (fromY + getMeasureImpl().getTrackImpl().getTabHeight() + ((stringSpacing / 2) * 5));
@@ -469,12 +454,11 @@ public class TGVoiceImpl extends TGVoice{
 			}
 			if (getDuration().getValue() >= TGDuration.QUARTER) {
 				layout.setTabNoteFooterStyle(painter);
-				painter.initPath();
+				painter.initPath(UIPainter.PATH_DRAW | UIPainter.PATH_FILL);
 				painter.setAntialias(false);
 				painter.setLineWidth( verticalLineWidth );
 				painter.moveTo(x, y1);
 				painter.lineTo(x, y2);
-				painter.closePath();
 				if (getDuration().getValue() >= TGDuration.EIGHTH) {
 					float x1 = 0;
 					float x2 = 0;
@@ -492,17 +476,16 @@ public class TGVoiceImpl extends TGVoice{
 					int index = ( getDuration().getIndex() - 2);
 					if(index > 0){
 						float height = (layout.getStringSpacing() / 2);
-						float direction = (getBeatGroup().getDirection() == TGBeatGroup.DIRECTION_DOWN ? 1f : -1f);
-						painter.setLineWidth( horizontalLineWidth );
-						painter.initPath();
 						for(int i = index; i > 0 ;i --){
 							painter.moveTo(fromX + x1, y2 + ((height - (i * height)) * direction));
 							painter.lineTo(fromX + x2, y2 + ((height - (i * height)) * direction));
+							painter.lineTo(fromX + x2, y2 + ((height - (i * height)) * direction) + (horizontalLineWidth * direction));
+							painter.lineTo(fromX + x1, y2 + ((height - (i * height)) * direction) + (horizontalLineWidth * direction));
+							painter.lineTo(fromX + x1, y2 + ((height - (i * height)) * direction));
 						}
-						painter.closePath();
-						painter.setLineWidth(1f * scale);
 					}
 				}
+				painter.closePath();
 			} else if (getDuration().getValue() == TGDuration.HALF) {
 				layout.setTabNoteFooterStyle(painter);
 				painter.initPath();
@@ -517,26 +500,15 @@ public class TGVoiceImpl extends TGVoice{
 			if (getDuration().isDotted() || getDuration().isDoubleDotted()) {
 				int joinedType = getJoinedType();
 				float posX = ((getDuration().getValue() > TGDuration.WHOLE)?((joinedType == TGVoiceImpl.JOINED_TYPE_NONE_RIGHT || joinedType == TGVoiceImpl.JOINED_TYPE_RIGHT)?(x+ (4.0f * scale)):(x- (5.0f * scale))):x);
-				float posY = (y2 - ((getDuration().getValue() >= TGDuration.EIGHTH)? ((stringSpacing / 2) * (getDuration().getIndex() - 2)):(1.0f * scale)));
-				paintDot(layout, painter, posX, posY,scale);
-			}
-			
-			//-------------tresillo--------------------------------------
-			if (!getDuration().getDivision().isEqual(TGDivisionType.NORMAL)) {
-				layout.setDivisionTypeStyle(painter);
-				painter.drawString(Integer.toString(getDuration().getDivision().getEnters()), (x - 3f),((fromY - getPaintPosition(TGTrackSpacing.POSITION_TABLATURE)) + getPaintPosition(TGTrackSpacing.POSITION_DIVISION_TYPE)));
+				float posY = (y2 - ((getDuration().getValue() >= TGDuration.EIGHTH ? ((stringSpacing / 2f) * (getDuration().getIndex() - 2)) : scale) * direction));
+				paintDot(layout, painter, posX, posY, scale);
 			}
 		}
 	}
 	
-	public void paintScoreBeat(TGLayout layout,TGPainter painter, float fromX, float fromY, float spacing){
+	public void paintScoreBeat(TGLayout layout,UIPainter painter, float fromX, float fromY, float spacing){
 		float vX = ( fromX + getPosX() + spacing );
 		
-		//division type
-		if (!getDuration().getDivision().isEqual(TGDivisionType.NORMAL)) {
-			layout.setDivisionTypeStyle(painter);
-			painter.drawString(Integer.toString(getDuration().getDivision().getEnters()),vX ,((fromY - getPaintPosition(TGTrackSpacing.POSITION_SCORE_MIDDLE_LINES)) + getPaintPosition(TGTrackSpacing.POSITION_DIVISION_TYPE)));
-		}
 		//dibujo el pie
 		if( getDuration().getValue() >= TGDuration.HALF ){
 			layout.setScoreNoteFooterStyle(painter);
@@ -555,7 +527,8 @@ public class TGVoiceImpl extends TGVoice{
 			float vY1 = fromY + ( direction == TGBeatGroup.DIRECTION_DOWN ? this.maxNote.getScorePosY() : this.minNote.getScorePosY() );
 			float vY2 = fromY + this.group.getY2(layout,getPosX() + spacing, key, clef);
 			
-			painter.initPath(TGPainter.PATH_FILL);
+			painter.setLineWidth(layout.getLineWidth(0));
+			painter.initPath(UIPainter.PATH_FILL);
 			painter.moveTo(vX + xMove - (0.5f * scale), vY1 + yMove);
 			painter.lineTo(vX + xMove + (0.5f * scale), vY1 + yMove);
 			painter.lineTo(vX + xMove + (0.5f * scale), vY2);
@@ -573,54 +546,85 @@ public class TGVoiceImpl extends TGVoice{
 						float hX = (fromX + xMove + getPosX() + spacing - (0.5f * scale));
 						float hY = ((fromY + this.group.getY2(layout,getPosX() + spacing,key,clef)) - ( (lineSpacing * 2)* dir )) ;
 						for(int i = 0; i <= index; i ++){
-							painter.initPath(TGPainter.PATH_FILL);
+							painter.initPath(UIPainter.PATH_FILL);
 							TGNotePainter.paintFooter(painter, hX, (hY - ( (i * (lineSpacing / 2.0f)) * dir)),dir,lineSpacing);
 							painter.closePath();
 						}
-					}else{
+					} else {
+						float hX = (getPosX() + spacing);
 						float hX1 = 0;
 						float hX2 = 0;
+						float hY1 = 0;
+						float hY2 = 0;
+						float currHX1 = 0;
+						float currHX2 = 0;
+						float hLineWidth = layout.getLineWidth(2);
+						float hLineMargin = hLineWidth;
+						int nIndex = (this.next != null ? this.next.getDuration().getIndex() - 3 : -1);
+						int pIndex = (this.previous != null ? this.previous.getDuration().getIndex() - 3 : -1);
+						boolean pathInitialized = false;
+						
 						if(joinedType == TGVoiceImpl.JOINED_TYPE_NONE_RIGHT){
-							hX1 = getPosX() + spacing;
+							hX1 = hX;
 							hX2 = getPosX() + spacing + (6f * scale);
 						}else if(joinedType == TGVoiceImpl.JOINED_TYPE_NONE_LEFT){
 							hX1 = getPosX() + spacing - (5f * scale);
-							hX2 = getPosX() + spacing;
+							hX2 = hX;
 						}else{
 							hX1 = getJoin1().getPosX() + getJoin1().getBeatImpl().getSpacing(layout);
 							hX2 = getJoin2().getPosX() + getJoin2().getBeatImpl().getSpacing(layout);
 						}
-						float hY1 = fromY + this.group.getY2(layout,hX1,key,clef);
-						float hY2 = fromY + this.group.getY2(layout,hX2,key,clef);
 						
-						painter.setLineWidth(TGPainter.THINNEST_LINE_WIDTH);
-						painter.initPath(TGPainter.PATH_FILL);
-						for(int i = 0; i <= index; i ++){
-							painter.moveTo(fromX + xMove + hX1 - (0.5f * scale), hY1 - ((i * (5f * scale)) * dir) - (1.5f * scale));
-							painter.lineTo(fromX + xMove + hX1 - (0.5f * scale), hY1 - ((i * (5f * scale)) * dir) + (1.5f * scale));
-							painter.lineTo(fromX + xMove + hX2 + (0.5f * scale), hY2 - ((i * (5f * scale)) * dir) + (1.5f * scale));
-							painter.lineTo(fromX + xMove + hX2 + (0.5f * scale), hY2 - ((i * (5f * scale)) * dir) - (1.5f * scale));
-							painter.lineTo(fromX + xMove + hX1 - (0.5f * scale), hY1 - ((i * (5f * scale)) * dir) - (1.5f * scale));
+						for(int i = 0; i <= index; i ++) {
+							currHX1 = hX1;
+							currHX2 = hX2;
+							if( this.previous != null && this.previous.getJoin2() != null && this.previous.getJoin2().equals(this) ) {
+								if((this.getJoin1() != null && this.getJoin1().equals(this.previous)) || i <= pIndex ) {
+									currHX1 = hX;
+								}
+							}
+							if( this.next != null && this.next.getJoin1() != null && this.next.getJoin1().equals(this) ) {
+								if((this.getJoin1() == null || !this.getJoin2().equals(this.next)) && i <= nIndex ) {
+									currHX2 = hX;
+								}
+							}
+							if( currHX1 != currHX2 ) {
+								if(!pathInitialized) {
+									pathInitialized = true;
+									painter.initPath(UIPainter.PATH_FILL);
+								}
+								hY1 = fromY + this.group.getY2(layout, currHX1, key, clef);
+								hY2 = fromY + this.group.getY2(layout, currHX2, key, clef);
+								
+								painter.moveTo(fromX + xMove + currHX1 - (0.5f * scale), hY1 - ((i * ((hLineWidth * 2f) + hLineMargin)) * dir) - hLineWidth);
+								painter.lineTo(fromX + xMove + currHX1 - (0.5f * scale), hY1 - ((i * ((hLineWidth * 2f) + hLineMargin)) * dir) + hLineWidth);
+								painter.lineTo(fromX + xMove + currHX2 + (0.5f * scale), hY2 - ((i * ((hLineWidth * 2f) + hLineMargin)) * dir) + hLineWidth);
+								painter.lineTo(fromX + xMove + currHX2 + (0.5f * scale), hY2 - ((i * ((hLineWidth * 2f) + hLineMargin)) * dir) - hLineWidth);
+								painter.lineTo(fromX + xMove + currHX1 - (0.5f * scale), hY1 - ((i * ((hLineWidth * 2f) + hLineMargin)) * dir) - hLineWidth);
+							}
+						}
+						
+						if( pathInitialized) {
+							painter.closePath();
 						}
-						painter.closePath();
-						painter.setLineWidth(1f * scale);
 					}
 				}
 			}
 		}
 	}
 	
-	public void paintDot(TGLayout layout,TGPainter painter,float fromX, float fromY,float scale){
+	public void paintDot(TGLayout layout,UIPainter painter,float fromX, float fromY, float scale){
 		float dotSize = (3.0f * scale);
 		float posX = fromX;
 		float posY = fromY;
 		layout.setDotStyle(painter);
-		painter.initPath(TGPainter.PATH_FILL);
-		painter.moveTo(posX - (dotSize / 2), posY - (dotSize / 2));
-		painter.addOval(posX - (dotSize / 2), posY - (dotSize / 2), dotSize,dotSize);
+		painter.setLineWidth(layout.getLineWidth(0));
+		painter.initPath(UIPainter.PATH_FILL);
+		painter.moveTo(posX, posY);
+		painter.addCircle(posX, posY, dotSize);
 		if(getDuration().isDoubleDotted()){
-			painter.moveTo(posX + (dotSize + 2) - (dotSize / 2), posY - (dotSize / 2));
-			painter.addOval(posX + (dotSize + 2) - (dotSize / 2), posY - (dotSize / 2), dotSize,dotSize);
+			painter.moveTo(posX + (dotSize + (2f * scale)), posY);
+			painter.addCircle(posX + (dotSize + (2f * scale)), posY, dotSize);
 		}
 		painter.closePath();
 	}
