@@ -17,6 +17,8 @@ import org.herac.tuxguitar.song.models.TGNote;
 import org.herac.tuxguitar.song.models.TGSong;
 import org.herac.tuxguitar.song.models.TGString;
 import org.herac.tuxguitar.song.models.TGTrack;
+import org.herac.tuxguitar.thread.TGThreadLoop;
+import org.herac.tuxguitar.thread.TGThreadManager;
 import org.herac.tuxguitar.util.TGContext;
 import org.herac.tuxguitar.util.TGLock;
 import org.herac.tuxguitar.util.singleton.TGSingletonFactory;
@@ -26,7 +28,7 @@ public class MidiPlayer{
 	
 	public static final int MAX_VOLUME = 10;
 	
-	private static final int TIMER_DELAY = 10;
+	private static final long TIMER_DELAY = 10;
 	
 	private TGContext context;
 	
@@ -82,11 +84,11 @@ public class MidiPlayer{
 	
 	private boolean tryOpenFistDevice;
 	
-	protected TGLock lock = new TGLock();
+	protected TGLock lock;
 	
 	private MidiPlayer(TGContext context) {
 		this.context = context;
-		this.lock = new TGLock();
+		this.lock = new TGLock(context);
 		this.volume = MAX_VOLUME;
 	}
 	
@@ -197,18 +199,15 @@ public class MidiPlayer{
 			this.addSequence();
 			this.updateTracks();
 			this.updateChannels();
-			this.updatePrograms();
-			this.updateControllers();
-			this.updateDefaultControllers();
 			this.setMetronomeEnabled(isMetronomeEnabled());
 			this.getCountDown().setTempoPercent(getMode().getCurrentPercent());
 			this.changeTickPosition();
 			
-			new Thread(new Runnable() {
+			TGThreadManager.getInstance(this.context).start(new Runnable() {
 				public void run() {
-					runPlayProcess(notifyStarted);
+					runPlayStartProcess(notifyStarted);
 				}
-			}).start();
+			});
 		}catch (Throwable throwable) {
 			this.reset();
 			throw new MidiPlayerException(throwable.getMessage(),throwable);
@@ -217,7 +216,7 @@ public class MidiPlayer{
 		}
 	}
 	
-	public void runPlayProcess(boolean notifyStarted) {
+	public void runPlayStartProcess(boolean notifyStarted) {
 		try {
 			// Start
 			if( notifyStarted ){
@@ -246,8 +245,26 @@ public class MidiPlayer{
 			}
 			
 			// Play loop
-			Object sequencerLock = new Object();
-			while( this.getSequencer().isRunning() && this.isRunning()) {
+			runPlayLoop();
+		}catch (Throwable throwable) {
+			this.reset();
+			
+			throwable.printStackTrace();
+		}
+	}
+	
+	public void runPlayLoop() {
+		TGThreadManager.getInstance(this.context).loop(new TGThreadLoop() {
+			public Long process() {
+				return (runPlayLoopProcess() ? TIMER_DELAY : BREAK);
+			}
+		});
+	}
+	
+	public boolean runPlayLoopProcess() {
+		try {
+			// Play loop
+			if( this.getSequencer().isRunning() && this.isRunning()) {
 				try {
 					this.lock();
 					
@@ -258,11 +275,22 @@ public class MidiPlayer{
 				} finally {
 					this.unlock();
 				}
-				synchronized(sequencerLock) {
-					sequencerLock.wait( TIMER_DELAY );
-				}
+				return true;
 			}
 			
+			else {
+				runPlayEndProcess();
+			}
+		}catch (Throwable throwable) {
+			this.reset();
+			
+			throwable.printStackTrace();
+		}
+		return false;
+	}
+	
+	public void runPlayEndProcess() {
+		try {
 			// Finish
 			try {
 				this.lock();
@@ -360,8 +388,10 @@ public class MidiPlayer{
 			
 			this.volume = volume;
 			if (this.isRunning()) {
-				this.updateControllers();
+				this.updateChannels();
 			}
+		} catch (MidiPlayerException e) {
+			e.printStackTrace();
 		} finally {
 			this.unlock();
 		}
@@ -555,45 +585,51 @@ public class MidiPlayer{
 				}
 			}
 			
-			this.updateParameters();
-		} finally {
-			this.unlock();
-		}
-	}
-	
-	public void updateParameters(){
-		try {
-			this.lock();
-			
-			Iterator<TGChannel> tgChannels = this.getSong().getChannels();
+			// Update channels
+			tgChannels = this.getSong().getChannels();
 			while( tgChannels.hasNext() ){
-				TGChannel tgChannel = (TGChannel) tgChannels.next();
-				this.updateParameters(tgChannel);
+				this.updateChannel(tgChannels.next());
 			}
 		} finally {
 			this.unlock();
 		}
 	}
 	
-	public void updateParameters(TGChannel tgChannel){
+	public void updateChannel(TGChannel channel) {
 		try {
 			this.lock();
 			
+			this.updateParameters(channel);
+			this.updateProgram(channel);
+			this.updateController(channel);
+			this.updateDefaultControllers(channel);
+		} finally {
+			this.unlock();
+		}
+	}
+	
+	private void updateParameters(TGChannel tgChannel) {
+		try {
+			this.lock();
+			this.updateParameter(tgChannel, MidiParameters.SENDING_PARAMS, Boolean.TRUE.toString());
+			
 			Iterator<TGChannelParameter> parameters = tgChannel.getParameters();
 			while( parameters.hasNext() ){
 				TGChannelParameter tgChannelParameter = (TGChannelParameter) parameters.next();
-				this.updateParameters(tgChannel, tgChannelParameter);
+				this.updateParameter(tgChannel, tgChannelParameter.getKey(), tgChannelParameter.getValue());
 			}
+			
+			this.updateParameter(tgChannel, MidiParameters.SENDING_PARAMS, Boolean.FALSE.toString());
 		} finally {
 			this.unlock();
 		}
 	}
 	
-	public void updateParameters(TGChannel tgChannel, TGChannelParameter tgChannelParameter){
+	private void updateParameter(TGChannel tgChannel, String key, String value){
 		try {
 			this.lock();
 			
-			getOutputTransmitter().sendParameter(tgChannel.getChannelId(), tgChannelParameter.getKey(), tgChannelParameter.getValue());
+			getOutputTransmitter().sendParameter(tgChannel.getChannelId(), key, value);
 		} catch (MidiPlayerException e) {
 			e.printStackTrace();
 		} finally {
@@ -601,38 +637,6 @@ public class MidiPlayer{
 		}
 	}
 	
-	private void updateDefaultControllers(){
-		try {
-			this.lock();
-			
-			Iterator<TGChannel> tgChannels = this.getSong().getChannels();
-			while( tgChannels.hasNext() ){
-				TGChannel tgChannel = (TGChannel) tgChannels.next();
-				getOutputTransmitter().sendControlChange(tgChannel.getChannelId(),MidiControllers.RPN_MSB,0);
-				getOutputTransmitter().sendControlChange(tgChannel.getChannelId(),MidiControllers.RPN_LSB,0);
-				getOutputTransmitter().sendControlChange(tgChannel.getChannelId(),MidiControllers.DATA_ENTRY_MSB,12);
-				getOutputTransmitter().sendControlChange(tgChannel.getChannelId(),MidiControllers.DATA_ENTRY_LSB, 0);
-			}
-		} catch (MidiPlayerException e) {
-			e.printStackTrace();
-		} finally {
-			this.unlock();
-		}
-	}
-	
-	public void updatePrograms() {
-		try {
-			this.lock();
-			
-			Iterator<TGChannel> it = this.getSong().getChannels();
-			while(it.hasNext()){
-				updateProgram((TGChannel)it.next());
-			}
-		} finally {
-			this.unlock();
-		}
-	}
-	
 	private void updateProgram(TGChannel channel) {
 		try {
 			this.lock();
@@ -660,20 +664,6 @@ public class MidiPlayer{
 		}
 	}
 	
-	public void updateControllers() {
-		try{
-			this.lock();
-			
-			Iterator<TGChannel> channelsIt = this.getSong().getChannels();
-			while( channelsIt.hasNext() ){
-				this.updateController( (TGChannel)channelsIt.next() );
-			}
-			this.afterUpdate();
-		} finally {
-			this.unlock();
-		}
-	}
-	
 	private void updateController(TGChannel channel) {
 		try{
 			this.lock();
@@ -691,7 +681,7 @@ public class MidiPlayer{
 		}
 	}
 	
-	private void updateController(int channelId,int volume,int balance,int chorus, int reverb,int phaser, int tremolo, int expression) {
+	private void updateController(int channelId, int volume, int balance, int chorus, int reverb, int phaser, int tremolo, int expression) {
 		try{
 			this.lock();
 			
@@ -709,6 +699,21 @@ public class MidiPlayer{
 		}
 	}
 	
+	private void updateDefaultControllers(TGChannel tgChannel){
+		try {
+			this.lock();
+			
+			getOutputTransmitter().sendControlChange(tgChannel.getChannelId(),MidiControllers.RPN_MSB,0);
+			getOutputTransmitter().sendControlChange(tgChannel.getChannelId(),MidiControllers.RPN_LSB,0);
+			getOutputTransmitter().sendControlChange(tgChannel.getChannelId(),MidiControllers.DATA_ENTRY_MSB,12);
+			getOutputTransmitter().sendControlChange(tgChannel.getChannelId(),MidiControllers.DATA_ENTRY_LSB, 0);
+		} catch (MidiPlayerException e) {
+			e.printStackTrace();
+		} finally {
+			this.unlock();
+		}
+	}
+		
 	public void updateTracks() {
 		try{
 			this.lock();
@@ -809,11 +814,11 @@ public class MidiPlayer{
 					beat[i][1] = note.getVelocity();
 				}
 				
-				new Thread(new Runnable() {
+				TGThreadManager.getInstance(this.context).start(new Runnable() {
 					public void run() {
 						MidiPlayer.this.playBeat(channelId, bank, program, volume, balance, chorus, reverb, phaser, tremolo, beat);
 					}
-				}).start();
+				});
 			}
 		} finally {
 			this.unlock();
@@ -828,15 +833,6 @@ public class MidiPlayer{
 		try {
 			this.updateChannels();
 			
-			this.getOutputTransmitter().sendControlChange(channelId,MidiControllers.BANK_SELECT, bank);
-			this.getOutputTransmitter().sendControlChange(channelId,MidiControllers.VOLUME, volume);
-			this.getOutputTransmitter().sendControlChange(channelId,MidiControllers.BALANCE, balance);
-			this.getOutputTransmitter().sendControlChange(channelId,MidiControllers.CHORUS, chorus);
-			this.getOutputTransmitter().sendControlChange(channelId,MidiControllers.REVERB, reverb);
-			this.getOutputTransmitter().sendControlChange(channelId,MidiControllers.PHASER, phaser);
-			this.getOutputTransmitter().sendControlChange(channelId,MidiControllers.TREMOLO, tremolo);
-			this.getOutputTransmitter().sendProgramChange(channelId,program);
-			
 			Object sync = new Object();
 			
 			for(int i = 0; i < beat.length; i ++){
