@@ -2,6 +2,7 @@ package org.herac.tuxguitar.tray;
 
 import org.eclipse.swt.widgets.TrayItem;
 import org.herac.tuxguitar.app.TuxGuitar;
+import org.herac.tuxguitar.ui.swt.resource.SWTImage;
 
 public class TGTrayIcon {
 	
@@ -17,7 +18,7 @@ public class TGTrayIcon {
 	
 	public void loadImage(){
 		if( this.item != null && !this.item.isDisposed() ){
-			this.item.setImage(TuxGuitar.getInstance().getIconManager().getAppIcon24());
+			this.item.setImage(((SWTImage) TuxGuitar.getInstance().getIconManager().getAppIcon24()).getHandle());
 		}
 	}
 }
