@@ -29,12 +29,11 @@ import org.herac.tuxguitar.app.action.impl.effects.TGOpenTremoloPickingDialogAct
 import org.herac.tuxguitar.app.action.impl.effects.TGOpenTrillDialogAction;
 import org.herac.tuxguitar.app.action.impl.file.TGCloseAllDocumentsAction;
 import org.herac.tuxguitar.app.action.impl.file.TGCloseCurrentDocumentAction;
+import org.herac.tuxguitar.app.action.impl.file.TGCloseDocumentAction;
 import org.herac.tuxguitar.app.action.impl.file.TGCloseDocumentsAction;
 import org.herac.tuxguitar.app.action.impl.file.TGCloseOtherDocumentsAction;
 import org.herac.tuxguitar.app.action.impl.file.TGExitAction;
-import org.herac.tuxguitar.app.action.impl.file.TGExportFileAction;
 import org.herac.tuxguitar.app.action.impl.file.TGExportSongAction;
-import org.herac.tuxguitar.app.action.impl.file.TGImportFileAction;
 import org.herac.tuxguitar.app.action.impl.file.TGImportSongAction;
 import org.herac.tuxguitar.app.action.impl.file.TGOpenFileAction;
 import org.herac.tuxguitar.app.action.impl.file.TGOpenURLAction;
@@ -53,6 +52,10 @@ import org.herac.tuxguitar.app.action.impl.insert.TGOpenTextDialogAction;
 import org.herac.tuxguitar.app.action.impl.layout.TGSetChordDiagramEnabledAction;
 import org.herac.tuxguitar.app.action.impl.layout.TGSetChordNameEnabledAction;
 import org.herac.tuxguitar.app.action.impl.layout.TGSetCompactViewAction;
+import org.herac.tuxguitar.app.action.impl.layout.TGSetLayoutScaleAction;
+import org.herac.tuxguitar.app.action.impl.layout.TGSetLayoutScaleDecrementAction;
+import org.herac.tuxguitar.app.action.impl.layout.TGSetLayoutScaleIncrementAction;
+import org.herac.tuxguitar.app.action.impl.layout.TGSetLayoutScaleResetAction;
 import org.herac.tuxguitar.app.action.impl.layout.TGSetLinearLayoutAction;
 import org.herac.tuxguitar.app.action.impl.layout.TGSetMultitrackViewAction;
 import org.herac.tuxguitar.app.action.impl.layout.TGSetPageLayoutAction;
@@ -68,7 +71,6 @@ import org.herac.tuxguitar.app.action.impl.marker.TGOpenMarkerEditorAction;
 import org.herac.tuxguitar.app.action.impl.marker.TGRemoveMarkerAction;
 import org.herac.tuxguitar.app.action.impl.marker.TGToggleMarkerListAction;
 import org.herac.tuxguitar.app.action.impl.marker.TGUpdateMarkerAction;
-import org.herac.tuxguitar.app.action.impl.measure.TGCopyMeasureAction;
 import org.herac.tuxguitar.app.action.impl.measure.TGGoFirstMeasureAction;
 import org.herac.tuxguitar.app.action.impl.measure.TGGoLastMeasureAction;
 import org.herac.tuxguitar.app.action.impl.measure.TGGoNextMeasureAction;
@@ -78,7 +80,6 @@ import org.herac.tuxguitar.app.action.impl.measure.TGOpenMeasureCleanDialogActio
 import org.herac.tuxguitar.app.action.impl.measure.TGOpenMeasureCopyDialogAction;
 import org.herac.tuxguitar.app.action.impl.measure.TGOpenMeasurePasteDialogAction;
 import org.herac.tuxguitar.app.action.impl.measure.TGOpenMeasureRemoveDialogAction;
-import org.herac.tuxguitar.app.action.impl.measure.TGPasteMeasureAction;
 import org.herac.tuxguitar.app.action.impl.note.TGOpenBeatMoveDialogAction;
 import org.herac.tuxguitar.app.action.impl.note.TGOpenStrokeDownDialogAction;
 import org.herac.tuxguitar.app.action.impl.note.TGOpenStrokeUpDialogAction;
@@ -104,6 +105,7 @@ import org.herac.tuxguitar.app.action.impl.track.TGGoNextTrackAction;
 import org.herac.tuxguitar.app.action.impl.track.TGGoPreviousTrackAction;
 import org.herac.tuxguitar.app.action.impl.track.TGGoToTrackAction;
 import org.herac.tuxguitar.app.action.impl.track.TGOpenTrackPropertiesDialogAction;
+import org.herac.tuxguitar.app.action.impl.track.TGOpenTrackTuningDialogAction;
 import org.herac.tuxguitar.app.action.impl.track.TGToggleLyricEditorAction;
 import org.herac.tuxguitar.app.action.impl.transport.TGOpenTransportModeDialogAction;
 import org.herac.tuxguitar.app.action.impl.transport.TGTransportCountDownAction;
@@ -117,15 +119,17 @@ import org.herac.tuxguitar.app.action.impl.view.TGHideExternalBeatAction;
 import org.herac.tuxguitar.app.action.impl.view.TGOpenViewAction;
 import org.herac.tuxguitar.app.action.impl.view.TGShowExternalBeatAction;
 import org.herac.tuxguitar.app.action.impl.view.TGToggleChannelsDialogAction;
+import org.herac.tuxguitar.app.action.impl.view.TGToggleEditToolbarAction;
 import org.herac.tuxguitar.app.action.impl.view.TGToggleFretBoardEditorAction;
+import org.herac.tuxguitar.app.action.impl.view.TGToggleMainToolbarAction;
 import org.herac.tuxguitar.app.action.impl.view.TGToggleMatrixEditorAction;
 import org.herac.tuxguitar.app.action.impl.view.TGTogglePianoEditorAction;
-import org.herac.tuxguitar.app.action.impl.view.TGToggleToolbarsAction;
 import org.herac.tuxguitar.app.action.impl.view.TGToggleTransportDialogAction;
 import org.herac.tuxguitar.app.action.impl.view.TGToggleViewAction;
 import org.herac.tuxguitar.app.action.listener.cache.TGUpdateController;
 import org.herac.tuxguitar.app.action.listener.cache.controller.TGUpdateAddedMeasureController;
 import org.herac.tuxguitar.app.action.listener.cache.controller.TGUpdateAddedTrackController;
+import org.herac.tuxguitar.app.action.listener.cache.controller.TGUpdateChannelsController;
 import org.herac.tuxguitar.app.action.listener.cache.controller.TGUpdateItemsController;
 import org.herac.tuxguitar.app.action.listener.cache.controller.TGUpdateItemsOnSuccessController;
 import org.herac.tuxguitar.app.action.listener.cache.controller.TGUpdateLoadedSongController;
@@ -136,7 +140,6 @@ import org.herac.tuxguitar.app.action.listener.cache.controller.TGUpdateModified
 import org.herac.tuxguitar.app.action.listener.cache.controller.TGUpdateModifiedNoteController;
 import org.herac.tuxguitar.app.action.listener.cache.controller.TGUpdateModifiedVelocityController;
 import org.herac.tuxguitar.app.action.listener.cache.controller.TGUpdatePlayerTracksController;
-import org.herac.tuxguitar.app.action.listener.cache.controller.TGUpdateReadedURLController;
 import org.herac.tuxguitar.app.action.listener.cache.controller.TGUpdateRemovedMeasureController;
 import org.herac.tuxguitar.app.action.listener.cache.controller.TGUpdateRemovedTrackController;
 import org.herac.tuxguitar.app.action.listener.cache.controller.TGUpdateSavedSongController;
@@ -161,6 +164,7 @@ import org.herac.tuxguitar.editor.action.composition.TGChangeTripletFeelAction;
 import org.herac.tuxguitar.editor.action.composition.TGRepeatAlternativeAction;
 import org.herac.tuxguitar.editor.action.composition.TGRepeatCloseAction;
 import org.herac.tuxguitar.editor.action.composition.TGRepeatOpenAction;
+import org.herac.tuxguitar.editor.action.duration.TGChangeDivisionTypeDurationAction;
 import org.herac.tuxguitar.editor.action.duration.TGChangeDottedDurationAction;
 import org.herac.tuxguitar.editor.action.duration.TGChangeDoubleDottedDurationAction;
 import org.herac.tuxguitar.editor.action.duration.TGDecrementDurationAction;
@@ -205,8 +209,10 @@ import org.herac.tuxguitar.editor.action.measure.TGAddMeasureAction;
 import org.herac.tuxguitar.editor.action.measure.TGAddMeasureListAction;
 import org.herac.tuxguitar.editor.action.measure.TGCleanMeasureAction;
 import org.herac.tuxguitar.editor.action.measure.TGCleanMeasureListAction;
+import org.herac.tuxguitar.editor.action.measure.TGCopyMeasureAction;
 import org.herac.tuxguitar.editor.action.measure.TGCopyMeasureFromAction;
 import org.herac.tuxguitar.editor.action.measure.TGInsertMeasuresAction;
+import org.herac.tuxguitar.editor.action.measure.TGPasteMeasureAction;
 import org.herac.tuxguitar.editor.action.measure.TGRemoveMeasureAction;
 import org.herac.tuxguitar.editor.action.measure.TGRemoveMeasureRangeAction;
 import org.herac.tuxguitar.editor.action.note.TGChangeNoteAction;
@@ -252,6 +258,7 @@ import org.herac.tuxguitar.editor.action.track.TGSetTrackLyricsAction;
 import org.herac.tuxguitar.editor.action.track.TGSetTrackMuteAction;
 import org.herac.tuxguitar.editor.action.track.TGSetTrackNameAction;
 import org.herac.tuxguitar.editor.action.track.TGSetTrackSoloAction;
+import org.herac.tuxguitar.editor.action.track.TGSetTrackStringCountAction;
 import org.herac.tuxguitar.editor.undo.TGUndoableActionController;
 import org.herac.tuxguitar.editor.undo.impl.channel.TGUndoableChannelGenericController;
 import org.herac.tuxguitar.editor.undo.impl.channel.TGUndoableModifyChannelController;
@@ -292,6 +299,7 @@ public class TGActionConfigMap extends TGActionMap<TGActionConfig> {
 	private static final TGUpdateController UPDATE_SONG_CTL = new TGUpdateSongController();
 	private static final TGUpdateController UPDATE_SONG_LOADED_CTL = new TGUpdateLoadedSongController();
 	private static final TGUpdateController UPDATE_SONG_SAVED_CTL = new TGUpdateSavedSongController();
+	private static final TGUpdateController UPDATE_CHANNELS_CTL = new TGUpdateChannelsController();
 	
 	private static final TGUndoableActionController UNDOABLE_SONG_GENERIC = new TGUndoableSongGenericController();
 	private static final TGUndoableActionController UNDOABLE_MEASURE_GENERIC = new TGUndoableMeasureGenericController();
@@ -304,7 +312,7 @@ public class TGActionConfigMap extends TGActionMap<TGActionConfig> {
 	
 	public void createConfigMap() {
 		//system actions
-		this.map(TGDisposeAction.NAME, SYNC_THREAD | SAVE_BEFORE);
+		this.map(TGDisposeAction.NAME, LOCKABLE | SYNC_THREAD | SAVE_BEFORE);
 		
 		//file actions
 		this.map(TGLoadSongAction.NAME, LOCKABLE | STOP_TRANSPORT, UPDATE_SONG_LOADED_CTL);
@@ -315,17 +323,16 @@ public class TGActionConfigMap extends TGActionMap<TGActionConfig> {
 		this.map(TGWriteFileAction.NAME, LOCKABLE, new TGUpdateWrittenFileController());
 		this.map(TGSaveAsFileAction.NAME, LOCKABLE | SYNC_THREAD | SHORTCUT);
 		this.map(TGSaveFileAction.NAME, LOCKABLE | SYNC_THREAD | SHORTCUT);
-		this.map(TGReadURLAction.NAME, LOCKABLE | STOP_TRANSPORT, new TGUpdateReadedURLController());
+		this.map(TGReadURLAction.NAME, LOCKABLE | STOP_TRANSPORT, UPDATE_ITEMS_CTL);
 		this.map(TGOpenFileAction.NAME, LOCKABLE | SYNC_THREAD | SHORTCUT);
 		this.map(TGImportSongAction.NAME, LOCKABLE);
-		this.map(TGImportFileAction.NAME, LOCKABLE | SYNC_THREAD);
 		this.map(TGExportSongAction.NAME, LOCKABLE);
-		this.map(TGExportFileAction.NAME, LOCKABLE | SYNC_THREAD);
 		this.map(TGCloseDocumentsAction.NAME, LOCKABLE | SAVE_BEFORE, UPDATE_ITEMS_CTL);
+		this.map(TGCloseDocumentAction.NAME, LOCKABLE | STOP_TRANSPORT);
 		this.map(TGCloseCurrentDocumentAction.NAME, LOCKABLE | STOP_TRANSPORT);
 		this.map(TGCloseOtherDocumentsAction.NAME, LOCKABLE);
 		this.map(TGCloseAllDocumentsAction.NAME, LOCKABLE | STOP_TRANSPORT);
-		this.map(TGExitAction.NAME, SYNC_THREAD);
+		this.map(TGExitAction.NAME, LOCKABLE | SYNC_THREAD);
 		this.map(TGPrintAction.NAME, LOCKABLE | SHORTCUT);
 		this.map(TGPrintPreviewAction.NAME, LOCKABLE | SHORTCUT);
 		
@@ -346,53 +353,54 @@ public class TGActionConfigMap extends TGActionMap<TGActionConfig> {
 		
 		//caret actions
 		this.map(TGMoveToAction.NAME, LOCKABLE, new TGUpdateTransportPositionController());
-		this.map(TGGoRightAction.NAME, DISABLE_ON_PLAY | SHORTCUT);
-		this.map(TGGoLeftAction.NAME, DISABLE_ON_PLAY | SHORTCUT);
-		this.map(TGGoUpAction.NAME, DISABLE_ON_PLAY | SHORTCUT);
-		this.map(TGGoDownAction.NAME, DISABLE_ON_PLAY | SHORTCUT);
+		this.map(TGGoRightAction.NAME, LOCKABLE | DISABLE_ON_PLAY | SHORTCUT);
+		this.map(TGGoLeftAction.NAME, LOCKABLE | DISABLE_ON_PLAY | SHORTCUT);
+		this.map(TGGoUpAction.NAME, LOCKABLE | DISABLE_ON_PLAY | SHORTCUT);
+		this.map(TGGoDownAction.NAME, LOCKABLE | DISABLE_ON_PLAY | SHORTCUT);
 		
 		//song actions
 		this.map(TGCopySongFromAction.NAME, LOCKABLE, UPDATE_SONG_CTL, UNDOABLE_SONG_GENERIC);
-		this.map(TGClearSongAction.NAME, DISABLE_ON_PLAY);
+		this.map(TGClearSongAction.NAME, LOCKABLE | DISABLE_ON_PLAY);
 		
 		//track actions
 		this.map(TGAddNewTrackAction.NAME, LOCKABLE | DISABLE_ON_PLAY | SHORTCUT, new TGUpdateAddedTrackController(), new TGUndoableAddTrackController());
 		this.map(TGAddTrackAction.NAME, LOCKABLE | DISABLE_ON_PLAY, new TGUpdateAddedTrackController(), new TGUndoableAddTrackController());
 		this.map(TGSetTrackMuteAction.NAME, LOCKABLE, new TGUpdatePlayerTracksController(), new TGUndoableTrackSoloMuteController());
 		this.map(TGSetTrackSoloAction.NAME, LOCKABLE, new TGUpdatePlayerTracksController(), new TGUndoableTrackSoloMuteController());
-		this.map(TGChangeTrackMuteAction.NAME, SHORTCUT);
-		this.map(TGChangeTrackSoloAction.NAME, SHORTCUT);
+		this.map(TGChangeTrackMuteAction.NAME, LOCKABLE | SHORTCUT);
+		this.map(TGChangeTrackSoloAction.NAME, LOCKABLE | SHORTCUT);
 		this.map(TGCloneTrackAction.NAME, LOCKABLE | DISABLE_ON_PLAY | SHORTCUT, UPDATE_SONG_CTL, new TGUndoableCloneTrackController());
-		this.map(TGGoFirstTrackAction.NAME, SHORTCUT);
-		this.map(TGGoLastTrackAction.NAME, SHORTCUT);
-		this.map(TGGoNextTrackAction.NAME, SHORTCUT);
-		this.map(TGGoPreviousTrackAction.NAME, SHORTCUT);
-		this.map(TGGoToTrackAction.NAME);
+		this.map(TGGoFirstTrackAction.NAME, LOCKABLE | SHORTCUT);
+		this.map(TGGoLastTrackAction.NAME, LOCKABLE | SHORTCUT);
+		this.map(TGGoNextTrackAction.NAME, LOCKABLE | SHORTCUT);
+		this.map(TGGoPreviousTrackAction.NAME, LOCKABLE | SHORTCUT);
+		this.map(TGGoToTrackAction.NAME, LOCKABLE);
 		this.map(TGMoveTrackDownAction.NAME, LOCKABLE | SHORTCUT, UPDATE_SONG_CTL, new TGUndoableMoveTrackDownController());
 		this.map(TGMoveTrackUpAction.NAME, LOCKABLE | SHORTCUT, UPDATE_SONG_CTL, new TGUndoableMoveTrackUpController());
 		this.map(TGRemoveTrackAction.NAME, LOCKABLE | DISABLE_ON_PLAY | SHORTCUT, new TGUpdateRemovedTrackController(), new TGUndoableRemoveTrackController());
 		this.map(TGSetTrackInfoAction.NAME, LOCKABLE, UPDATE_ITEMS_CTL, new TGUndoableTrackInfoController());
-		this.map(TGSetTrackNameAction.NAME);
+		this.map(TGSetTrackNameAction.NAME, LOCKABLE);
 		this.map(TGSetTrackChannelAction.NAME, LOCKABLE | DISABLE_ON_PLAY, UPDATE_SONG_CTL, UNDOABLE_TRACK_GENERIC);
+		this.map(TGSetTrackStringCountAction.NAME, LOCKABLE | DISABLE_ON_PLAY, UPDATE_SONG_CTL, UNDOABLE_TRACK_GENERIC);
 		this.map(TGChangeTrackTuningAction.NAME, LOCKABLE | DISABLE_ON_PLAY, UPDATE_SONG_CTL, UNDOABLE_TRACK_GENERIC);
 		this.map(TGCopyTrackFromAction.NAME, LOCKABLE | DISABLE_ON_PLAY, UPDATE_SONG_CTL, UNDOABLE_TRACK_GENERIC);
 		this.map(TGSetTrackLyricsAction.NAME, LOCKABLE | DISABLE_ON_PLAY, UPDATE_ITEMS_CTL, new TGUndoableTrackLyricsController());
-		this.map(TGChangeTrackPropertiesAction.NAME, DISABLE_ON_PLAY);
+		this.map(TGChangeTrackPropertiesAction.NAME, LOCKABLE | DISABLE_ON_PLAY);
 		
 		//measure actions
 		this.map(TGAddMeasureAction.NAME, LOCKABLE | DISABLE_ON_PLAY, new TGUpdateAddedMeasureController(), new TGUndoableAddMeasureController());
-		this.map(TGAddMeasureListAction.NAME, DISABLE_ON_PLAY);
+		this.map(TGAddMeasureListAction.NAME, LOCKABLE | DISABLE_ON_PLAY);
 		this.map(TGCleanMeasureAction.NAME, LOCKABLE | DISABLE_ON_PLAY, UPDATE_MEASURE_CTL, UNDOABLE_MEASURE_GENERIC);
-		this.map(TGCleanMeasureListAction.NAME, DISABLE_ON_PLAY);
-		this.map(TGGoFirstMeasureAction.NAME, SHORTCUT);
-		this.map(TGGoLastMeasureAction.NAME, SHORTCUT);
-		this.map(TGGoNextMeasureAction.NAME, SHORTCUT);
-		this.map(TGGoPreviousMeasureAction.NAME, SHORTCUT);
+		this.map(TGCleanMeasureListAction.NAME, LOCKABLE |DISABLE_ON_PLAY);
+		this.map(TGGoFirstMeasureAction.NAME, LOCKABLE |SHORTCUT);
+		this.map(TGGoLastMeasureAction.NAME, LOCKABLE |SHORTCUT);
+		this.map(TGGoNextMeasureAction.NAME, LOCKABLE |SHORTCUT);
+		this.map(TGGoPreviousMeasureAction.NAME, LOCKABLE |SHORTCUT);
 		this.map(TGRemoveMeasureAction.NAME, LOCKABLE | DISABLE_ON_PLAY, new TGUpdateRemovedMeasureController(), new TGUndoableRemoveMeasureController());
-		this.map(TGRemoveMeasureRangeAction.NAME, DISABLE_ON_PLAY);
+		this.map(TGRemoveMeasureRangeAction.NAME, LOCKABLE |DISABLE_ON_PLAY);
 		this.map(TGCopyMeasureFromAction.NAME, LOCKABLE, UPDATE_MEASURE_CTL, UNDOABLE_MEASURE_GENERIC);
 		this.map(TGInsertMeasuresAction.NAME, LOCKABLE | DISABLE_ON_PLAY, UPDATE_SONG_CTL, UNDOABLE_SONG_GENERIC);
-		this.map(TGCopyMeasureAction.NAME, DISABLE_ON_PLAY);
+		this.map(TGCopyMeasureAction.NAME, LOCKABLE |DISABLE_ON_PLAY);
 		this.map(TGPasteMeasureAction.NAME, LOCKABLE | DISABLE_ON_PLAY, UPDATE_SONG_CTL, UNDOABLE_SONG_GENERIC);
 		
 		//beat actions
@@ -406,8 +414,8 @@ public class TGActionConfigMap extends TGActionMap<TGActionConfig> {
 		this.map(TGIncrementNoteSemitoneAction.NAME, LOCKABLE | DISABLE_ON_PLAY | SHORTCUT, UPDATE_MEASURE_CTL, UNDOABLE_MEASURE_GENERIC);
 		this.map(TGInsertRestBeatAction.NAME, LOCKABLE | DISABLE_ON_PLAY | SHORTCUT, UPDATE_MEASURE_CTL, UNDOABLE_MEASURE_GENERIC);
 		this.map(TGMoveBeatsAction.NAME, LOCKABLE | DISABLE_ON_PLAY, UPDATE_SONG_CTL, UNDOABLE_TRACK_GENERIC);
-		this.map(TGMoveBeatsLeftAction.NAME, DISABLE_ON_PLAY | SHORTCUT);
-		this.map(TGMoveBeatsRightAction.NAME, DISABLE_ON_PLAY | SHORTCUT);
+		this.map(TGMoveBeatsLeftAction.NAME, LOCKABLE | DISABLE_ON_PLAY | SHORTCUT);
+		this.map(TGMoveBeatsRightAction.NAME, LOCKABLE | DISABLE_ON_PLAY | SHORTCUT);
 		this.map(TGRemoveUnusedVoiceAction.NAME, LOCKABLE | DISABLE_ON_PLAY | SHORTCUT, UPDATE_MEASURE_CTL, UNDOABLE_MEASURE_GENERIC);
 		this.map(TGSetVoiceAutoAction.NAME, LOCKABLE | DISABLE_ON_PLAY | SHORTCUT, UPDATE_MEASURE_CTL, UNDOABLE_MEASURE_GENERIC);
 		this.map(TGSetVoiceDownAction.NAME, LOCKABLE | DISABLE_ON_PLAY | SHORTCUT, UPDATE_MEASURE_CTL, UNDOABLE_MEASURE_GENERIC);
@@ -420,7 +428,7 @@ public class TGActionConfigMap extends TGActionMap<TGActionConfig> {
 		this.map(TGInsertChordAction.NAME, LOCKABLE | DISABLE_ON_PLAY, UPDATE_MEASURE_CTL, UNDOABLE_MEASURE_GENERIC);
 		this.map(TGRemoveChordAction.NAME, LOCKABLE | DISABLE_ON_PLAY | SHORTCUT, UPDATE_MEASURE_CTL, UNDOABLE_MEASURE_GENERIC);
 		for( int i = 0 ; i < 10 ; i ++ ){
-			this.map(TGSetNoteFretNumberAction.getActionName(i), DISABLE_ON_PLAY | SHORTCUT);
+			this.map(TGSetNoteFretNumberAction.getActionName(i), LOCKABLE | DISABLE_ON_PLAY | SHORTCUT);
 		}
 		
 		//effect actions
@@ -447,20 +455,21 @@ public class TGActionConfigMap extends TGActionMap<TGActionConfig> {
 		
 		//duration actions
 		this.map(TGSetDurationAction.NAME, LOCKABLE | DISABLE_ON_PLAY, new TGUpdateModifiedDurationController(), UNDOABLE_MEASURE_GENERIC);
-		this.map(TGSetWholeDurationAction.NAME, DISABLE_ON_PLAY | SHORTCUT);
-		this.map(TGSetHalfDurationAction.NAME, DISABLE_ON_PLAY | SHORTCUT);
-		this.map(TGSetQuarterDurationAction.NAME, DISABLE_ON_PLAY | SHORTCUT);
-		this.map(TGSetEighthDurationAction.NAME, DISABLE_ON_PLAY | SHORTCUT);
-		this.map(TGSetSixteenthDurationAction.NAME, DISABLE_ON_PLAY | SHORTCUT);
-		this.map(TGSetThirtySecondDurationAction.NAME, DISABLE_ON_PLAY | SHORTCUT);
-		this.map(TGSetSixtyFourthDurationAction.NAME, DISABLE_ON_PLAY | SHORTCUT);
-		this.map(TGSetDivisionTypeDurationAction.NAME, DISABLE_ON_PLAY);
-		this.map(TGChangeDottedDurationAction.NAME, DISABLE_ON_PLAY | SHORTCUT);
-		this.map(TGChangeDoubleDottedDurationAction.NAME, DISABLE_ON_PLAY | SHORTCUT);
-		this.map(TGIncrementDurationAction.NAME, DISABLE_ON_PLAY | SHORTCUT);
-		this.map(TGDecrementDurationAction.NAME, DISABLE_ON_PLAY | SHORTCUT);
+		this.map(TGSetWholeDurationAction.NAME, LOCKABLE | DISABLE_ON_PLAY | SHORTCUT);
+		this.map(TGSetHalfDurationAction.NAME, LOCKABLE | DISABLE_ON_PLAY | SHORTCUT);
+		this.map(TGSetQuarterDurationAction.NAME, LOCKABLE | DISABLE_ON_PLAY | SHORTCUT);
+		this.map(TGSetEighthDurationAction.NAME, LOCKABLE | DISABLE_ON_PLAY | SHORTCUT);
+		this.map(TGSetSixteenthDurationAction.NAME, LOCKABLE | DISABLE_ON_PLAY | SHORTCUT);
+		this.map(TGSetThirtySecondDurationAction.NAME, LOCKABLE | DISABLE_ON_PLAY | SHORTCUT);
+		this.map(TGSetSixtyFourthDurationAction.NAME, LOCKABLE | DISABLE_ON_PLAY | SHORTCUT);
+		this.map(TGSetDivisionTypeDurationAction.NAME, LOCKABLE | DISABLE_ON_PLAY);
+		this.map(TGChangeDivisionTypeDurationAction.NAME, LOCKABLE | DISABLE_ON_PLAY | SHORTCUT);
+		this.map(TGChangeDottedDurationAction.NAME, LOCKABLE | DISABLE_ON_PLAY | SHORTCUT);
+		this.map(TGChangeDoubleDottedDurationAction.NAME, LOCKABLE | DISABLE_ON_PLAY | SHORTCUT);
+		this.map(TGIncrementDurationAction.NAME, LOCKABLE | DISABLE_ON_PLAY | SHORTCUT);
+		this.map(TGDecrementDurationAction.NAME, LOCKABLE | DISABLE_ON_PLAY | SHORTCUT);
 		this.map(TGChangeTempoAction.NAME, LOCKABLE | DISABLE_ON_PLAY, UPDATE_MEASURE_CTL, new TGUndoableTempoController());
-		this.map(TGChangeTempoRangeAction.NAME, DISABLE_ON_PLAY);
+		this.map(TGChangeTempoRangeAction.NAME, LOCKABLE | DISABLE_ON_PLAY);
 		this.map(TGChangeClefAction.NAME, LOCKABLE | DISABLE_ON_PLAY, UPDATE_SONG_CTL, new TGUndoableClefController());
 		this.map(TGChangeTimeSignatureAction.NAME, LOCKABLE | DISABLE_ON_PLAY, UPDATE_SONG_CTL, new TGUndoableTimeSignatureController());
 		this.map(TGChangeKeySignatureAction.NAME, LOCKABLE | DISABLE_ON_PLAY, UPDATE_SONG_CTL, new TGUndoableKeySignatureController());
@@ -473,30 +482,30 @@ public class TGActionConfigMap extends TGActionMap<TGActionConfig> {
 		this.map(TGRepeatAlternativeAction.NAME, LOCKABLE | DISABLE_ON_PLAY, UPDATE_MEASURE_CTL, new TGUndoableAltRepeatController());
 		
 		//channel actions
-		this.map(TGSetChannelsAction.NAME, LOCKABLE | DISABLE_ON_PLAY, UPDATE_ITEMS_CTL, UNDOABLE_CHANNEL_GENERIC);
-		this.map(TGAddChannelAction.NAME, LOCKABLE | DISABLE_ON_PLAY, UPDATE_ITEMS_CTL, UNDOABLE_CHANNEL_GENERIC);
-		this.map(TGAddNewChannelAction.NAME, LOCKABLE | DISABLE_ON_PLAY, UPDATE_ITEMS_CTL, UNDOABLE_CHANNEL_GENERIC);
-		this.map(TGRemoveChannelAction.NAME, LOCKABLE | DISABLE_ON_PLAY, UPDATE_ITEMS_CTL, UNDOABLE_CHANNEL_GENERIC);
+		this.map(TGSetChannelsAction.NAME, LOCKABLE | DISABLE_ON_PLAY, UPDATE_CHANNELS_CTL, UNDOABLE_CHANNEL_GENERIC);
+		this.map(TGAddChannelAction.NAME, LOCKABLE | DISABLE_ON_PLAY, UPDATE_CHANNELS_CTL, UNDOABLE_CHANNEL_GENERIC);
+		this.map(TGAddNewChannelAction.NAME, LOCKABLE | DISABLE_ON_PLAY, UPDATE_CHANNELS_CTL, UNDOABLE_CHANNEL_GENERIC);
+		this.map(TGRemoveChannelAction.NAME, LOCKABLE | DISABLE_ON_PLAY, UPDATE_CHANNELS_CTL, UNDOABLE_CHANNEL_GENERIC);
 		this.map(TGUpdateChannelAction.NAME, LOCKABLE, new TGUpdateModifiedChannelController(), new TGUndoableModifyChannelController());
 		
 		//transport actions
-		this.map(TGTransportPlayAction.NAME, SHORTCUT);
-		this.map(TGTransportStopAction.NAME, SHORTCUT);
-		this.map(TGTransportMetronomeAction.NAME, SHORTCUT);
-		this.map(TGTransportCountDownAction.NAME, SHORTCUT);
-		this.map(TGTransportModeAction.NAME);
-		this.map(TGTransportSetLoopSHeaderAction.NAME, SHORTCUT);
-		this.map(TGTransportSetLoopEHeaderAction.NAME, SHORTCUT);
+		this.map(TGTransportPlayAction.NAME, LOCKABLE | SHORTCUT);
+		this.map(TGTransportStopAction.NAME, LOCKABLE | SHORTCUT);
+		this.map(TGTransportMetronomeAction.NAME, LOCKABLE | SHORTCUT);
+		this.map(TGTransportCountDownAction.NAME, LOCKABLE | SHORTCUT);
+		this.map(TGTransportModeAction.NAME, LOCKABLE);
+		this.map(TGTransportSetLoopSHeaderAction.NAME, LOCKABLE | SHORTCUT);
+		this.map(TGTransportSetLoopEHeaderAction.NAME, LOCKABLE | SHORTCUT);
 		
 		//marker actions
 		this.map(TGUpdateMarkerAction.NAME, LOCKABLE, new TGUpdateModifiedMarkerController(), new TGUndoableMarkerGenericController());
 		this.map(TGRemoveMarkerAction.NAME, LOCKABLE, new TGUpdateModifiedMarkerController(), new TGUndoableMarkerGenericController());
-		this.map(TGModifyMarkerAction.NAME);
-		this.map(TGGoToMarkerAction.NAME);
-		this.map(TGGoPreviousMarkerAction.NAME, SHORTCUT);
-		this.map(TGGoNextMarkerAction.NAME, SHORTCUT);
-		this.map(TGGoFirstMarkerAction.NAME, SHORTCUT);
-		this.map(TGGoLastMarkerAction.NAME, SHORTCUT);
+		this.map(TGModifyMarkerAction.NAME, LOCKABLE);
+		this.map(TGGoToMarkerAction.NAME, LOCKABLE);
+		this.map(TGGoPreviousMarkerAction.NAME, LOCKABLE | SHORTCUT);
+		this.map(TGGoNextMarkerAction.NAME, LOCKABLE | SHORTCUT);
+		this.map(TGGoFirstMarkerAction.NAME, LOCKABLE | SHORTCUT);
+		this.map(TGGoLastMarkerAction.NAME, LOCKABLE | SHORTCUT);
 		
 		//layout actions
 		this.map(TGSetPageLayoutAction.NAME, LOCKABLE | SYNC_THREAD | SHORTCUT, UPDATE_SONG_CTL);
@@ -508,72 +517,75 @@ public class TGActionConfigMap extends TGActionMap<TGActionConfig> {
 		this.map(TGSetChordNameEnabledAction.NAME, LOCKABLE | SHORTCUT, UPDATE_SONG_CTL);
 		this.map(TGSetChordDiagramEnabledAction.NAME, LOCKABLE | SHORTCUT, UPDATE_SONG_CTL);
 		
+		this.map(TGSetLayoutScaleAction.NAME, LOCKABLE | SYNC_THREAD, UPDATE_SONG_CTL);
+		this.map(TGSetLayoutScaleIncrementAction.NAME, LOCKABLE | SYNC_THREAD, UPDATE_SONG_CTL);
+		this.map(TGSetLayoutScaleDecrementAction.NAME, LOCKABLE | SYNC_THREAD, UPDATE_SONG_CTL);
+		this.map(TGSetLayoutScaleResetAction.NAME, LOCKABLE | SYNC_THREAD, UPDATE_SONG_CTL);
+		
 		//tools
-		this.map(TGSelectScaleAction.NAME);
+		this.map(TGSelectScaleAction.NAME, LOCKABLE);
 		this.map(TGTransposeAction.NAME, LOCKABLE | DISABLE_ON_PLAY, UPDATE_SONG_CTL, UNDOABLE_SONG_GENERIC);
-		this.map(TGShowExternalBeatAction.NAME);
-		this.map(TGHideExternalBeatAction.NAME);
+		this.map(TGShowExternalBeatAction.NAME, LOCKABLE);
+		this.map(TGHideExternalBeatAction.NAME, LOCKABLE);
 		
 		//settings
-		this.map(TGReloadSettingsAction.NAME, LOCKABLE | SYNC_THREAD, UPDATE_SONG_CTL);
+		this.map(TGReloadSettingsAction.NAME, LOCKABLE, UPDATE_SONG_CTL);
 		this.map(TGReloadTitleAction.NAME, LOCKABLE | SYNC_THREAD, UPDATE_SONG_CTL);
 		this.map(TGReloadIconsAction.NAME, LOCKABLE | SYNC_THREAD, UPDATE_SONG_CTL);
 		this.map(TGReloadLanguageAction.NAME, LOCKABLE | SYNC_THREAD, UPDATE_SONG_CTL);
-		this.map(TGReloadMidiDevicesAction.NAME, LOCKABLE | SYNC_THREAD, UPDATE_SONG_CTL);
 		this.map(TGReloadStylesAction.NAME, LOCKABLE | SYNC_THREAD, UPDATE_SONG_CTL);
 		this.map(TGReloadTableSettingsAction.NAME, LOCKABLE | SYNC_THREAD, UPDATE_SONG_CTL);
-		this.map(TGOpenSettingsEditorAction.NAME, SHORTCUT);
-		this.map(TGOpenKeyBindingEditorAction.NAME, SHORTCUT);
-		this.map(TGOpenPluginListDialogAction.NAME, SHORTCUT);
+		this.map(TGReloadMidiDevicesAction.NAME, LOCKABLE, UPDATE_SONG_CTL);
+		this.map(TGOpenSettingsEditorAction.NAME, LOCKABLE | SYNC_THREAD | SHORTCUT);
+		this.map(TGOpenKeyBindingEditorAction.NAME, LOCKABLE | SYNC_THREAD | SHORTCUT);
+		this.map(TGOpenPluginListDialogAction.NAME, LOCKABLE | SYNC_THREAD | SHORTCUT);
 		
 		//gui actions
 		this.map(TGOpenViewAction.NAME, LOCKABLE | SYNC_THREAD);
 		this.map(TGToggleViewAction.NAME, LOCKABLE | SYNC_THREAD);
-		this.map(TGOpenSongInfoDialogAction.NAME, DISABLE_ON_PLAY | SHORTCUT);
-		this.map(TGOpenTempoDialogAction.NAME, DISABLE_ON_PLAY | SHORTCUT);
-		this.map(TGOpenClefDialogAction.NAME, DISABLE_ON_PLAY | SHORTCUT);
-		this.map(TGOpenKeySignatureDialogAction.NAME, DISABLE_ON_PLAY | SHORTCUT);
-		this.map(TGOpenTimeSignatureDialogAction.NAME, DISABLE_ON_PLAY | SHORTCUT);
-		this.map(TGOpenTripletFeelDialogAction.NAME, DISABLE_ON_PLAY | SHORTCUT);
-		this.map(TGOpenStrokeUpDialogAction.NAME, DISABLE_ON_PLAY | SHORTCUT);
-		this.map(TGOpenStrokeDownDialogAction.NAME, DISABLE_ON_PLAY | SHORTCUT);
-		this.map(TGOpenBendDialogAction.NAME, DISABLE_ON_PLAY | SHORTCUT);
-		this.map(TGOpenTrillDialogAction.NAME, DISABLE_ON_PLAY | SHORTCUT);
-		this.map(TGOpenTremoloPickingDialogAction.NAME, DISABLE_ON_PLAY | SHORTCUT);
-		this.map(TGOpenTremoloBarDialogAction.NAME, DISABLE_ON_PLAY | SHORTCUT);
-		this.map(TGOpenHarmonicDialogAction.NAME, DISABLE_ON_PLAY | SHORTCUT);
-		this.map(TGOpenGraceDialogAction.NAME, DISABLE_ON_PLAY | SHORTCUT);
-		this.map(TGOpenBeatMoveDialogAction.NAME, DISABLE_ON_PLAY | SHORTCUT);
-		this.map(TGOpenTextDialogAction.NAME, DISABLE_ON_PLAY | SHORTCUT);
-		this.map(TGOpenChordDialogAction.NAME, DISABLE_ON_PLAY | SHORTCUT);
-		this.map(TGOpenRepeatCloseDialogAction.NAME, DISABLE_ON_PLAY | SHORTCUT);
-		this.map(TGOpenRepeatAlternativeDialogAction.NAME, DISABLE_ON_PLAY | SHORTCUT);
-		this.map(TGOpenMeasureAddDialogAction.NAME, DISABLE_ON_PLAY | SHORTCUT);
-		this.map(TGOpenMeasureCleanDialogAction.NAME, DISABLE_ON_PLAY | SHORTCUT);
-		this.map(TGOpenMeasureRemoveDialogAction.NAME, DISABLE_ON_PLAY | SHORTCUT);
-		this.map(TGOpenMeasureCopyDialogAction.NAME, DISABLE_ON_PLAY | SHORTCUT);
-		this.map(TGOpenMeasurePasteDialogAction.NAME, DISABLE_ON_PLAY | SHORTCUT);
-		this.map(TGOpenTrackPropertiesDialogAction.NAME, DISABLE_ON_PLAY | SHORTCUT);
-		this.map(TGOpenScaleDialogAction.NAME, SHORTCUT);
-		this.map(TGOpenURLAction.NAME, SHORTCUT);
-		this.map(TGOpenTransportModeDialogAction.NAME, SHORTCUT);
-		this.map(TGOpenMarkerEditorAction.NAME, SHORTCUT);
-		this.map(TGOpenTransposeDialogAction.NAME, DISABLE_ON_PLAY | SHORTCUT);
-		this.map(TGToggleFretBoardEditorAction.NAME, SHORTCUT);
-		this.map(TGTogglePianoEditorAction.NAME, SHORTCUT);
-		this.map(TGToggleMatrixEditorAction.NAME, SHORTCUT);
-		this.map(TGToggleLyricEditorAction.NAME, SHORTCUT);
-		this.map(TGToggleChannelsDialogAction.NAME, SHORTCUT);
-		this.map(TGToggleBrowserAction.NAME, SHORTCUT);
-		this.map(TGToggleTransportDialogAction.NAME, SHORTCUT);
-		this.map(TGToggleMarkerListAction.NAME, SHORTCUT);
-		this.map(TGToggleToolbarsAction.NAME, SHORTCUT);
-		this.map(TGOpenDocumentationDialogAction.NAME, SHORTCUT);
-		this.map(TGOpenAboutDialogAction.NAME, SHORTCUT);
-	}
-	
-	private void map(String actionId) {
-		this.map(actionId, 0, UPDATE_ITEMS_CTL, null);
+		this.map(TGOpenSongInfoDialogAction.NAME, LOCKABLE | SYNC_THREAD |DISABLE_ON_PLAY | SHORTCUT);
+		this.map(TGOpenTempoDialogAction.NAME, LOCKABLE | SYNC_THREAD |DISABLE_ON_PLAY | SHORTCUT);
+		this.map(TGOpenClefDialogAction.NAME, LOCKABLE | SYNC_THREAD |DISABLE_ON_PLAY | SHORTCUT);
+		this.map(TGOpenKeySignatureDialogAction.NAME, LOCKABLE | SYNC_THREAD |DISABLE_ON_PLAY | SHORTCUT);
+		this.map(TGOpenTimeSignatureDialogAction.NAME, LOCKABLE | SYNC_THREAD |DISABLE_ON_PLAY | SHORTCUT);
+		this.map(TGOpenTripletFeelDialogAction.NAME, LOCKABLE | SYNC_THREAD |DISABLE_ON_PLAY | SHORTCUT);
+		this.map(TGOpenStrokeUpDialogAction.NAME, LOCKABLE | SYNC_THREAD |DISABLE_ON_PLAY | SHORTCUT);
+		this.map(TGOpenStrokeDownDialogAction.NAME, LOCKABLE | SYNC_THREAD |DISABLE_ON_PLAY | SHORTCUT);
+		this.map(TGOpenBendDialogAction.NAME, LOCKABLE | SYNC_THREAD |DISABLE_ON_PLAY | SHORTCUT);
+		this.map(TGOpenTrillDialogAction.NAME, LOCKABLE | SYNC_THREAD |DISABLE_ON_PLAY | SHORTCUT);
+		this.map(TGOpenTremoloPickingDialogAction.NAME, LOCKABLE | SYNC_THREAD |DISABLE_ON_PLAY | SHORTCUT);
+		this.map(TGOpenTremoloBarDialogAction.NAME, LOCKABLE | SYNC_THREAD |DISABLE_ON_PLAY | SHORTCUT);
+		this.map(TGOpenHarmonicDialogAction.NAME, LOCKABLE | SYNC_THREAD |DISABLE_ON_PLAY | SHORTCUT);
+		this.map(TGOpenGraceDialogAction.NAME, LOCKABLE | SYNC_THREAD |DISABLE_ON_PLAY | SHORTCUT);
+		this.map(TGOpenBeatMoveDialogAction.NAME, LOCKABLE | SYNC_THREAD |DISABLE_ON_PLAY | SHORTCUT);
+		this.map(TGOpenTextDialogAction.NAME, LOCKABLE | SYNC_THREAD |DISABLE_ON_PLAY | SHORTCUT);
+		this.map(TGOpenChordDialogAction.NAME, LOCKABLE | SYNC_THREAD |DISABLE_ON_PLAY | SHORTCUT);
+		this.map(TGOpenRepeatCloseDialogAction.NAME, LOCKABLE | SYNC_THREAD |DISABLE_ON_PLAY | SHORTCUT);
+		this.map(TGOpenRepeatAlternativeDialogAction.NAME, LOCKABLE | SYNC_THREAD |DISABLE_ON_PLAY | SHORTCUT);
+		this.map(TGOpenMeasureAddDialogAction.NAME, LOCKABLE | SYNC_THREAD |DISABLE_ON_PLAY | SHORTCUT);
+		this.map(TGOpenMeasureCleanDialogAction.NAME, LOCKABLE | SYNC_THREAD |DISABLE_ON_PLAY | SHORTCUT);
+		this.map(TGOpenMeasureRemoveDialogAction.NAME, LOCKABLE | SYNC_THREAD |DISABLE_ON_PLAY | SHORTCUT);
+		this.map(TGOpenMeasureCopyDialogAction.NAME, LOCKABLE | SYNC_THREAD |DISABLE_ON_PLAY | SHORTCUT);
+		this.map(TGOpenMeasurePasteDialogAction.NAME, LOCKABLE | SYNC_THREAD |DISABLE_ON_PLAY | SHORTCUT);
+		this.map(TGOpenTrackTuningDialogAction.NAME, LOCKABLE | SYNC_THREAD |DISABLE_ON_PLAY | SHORTCUT);
+		this.map(TGOpenTrackPropertiesDialogAction.NAME, LOCKABLE | SYNC_THREAD |DISABLE_ON_PLAY | SHORTCUT);
+		this.map(TGOpenScaleDialogAction.NAME, LOCKABLE | SYNC_THREAD |SHORTCUT);
+		this.map(TGOpenURLAction.NAME, LOCKABLE | SYNC_THREAD |SHORTCUT);
+		this.map(TGOpenTransportModeDialogAction.NAME, LOCKABLE | SYNC_THREAD |SHORTCUT);
+		this.map(TGOpenMarkerEditorAction.NAME, LOCKABLE | SYNC_THREAD |SHORTCUT);
+		this.map(TGOpenTransposeDialogAction.NAME, LOCKABLE | SYNC_THREAD |DISABLE_ON_PLAY | SHORTCUT);
+		this.map(TGToggleFretBoardEditorAction.NAME, LOCKABLE | SYNC_THREAD |SHORTCUT);
+		this.map(TGTogglePianoEditorAction.NAME, LOCKABLE | SYNC_THREAD |SHORTCUT);
+		this.map(TGToggleMatrixEditorAction.NAME, LOCKABLE | SYNC_THREAD |SHORTCUT);
+		this.map(TGToggleLyricEditorAction.NAME, LOCKABLE | SYNC_THREAD |SHORTCUT);
+		this.map(TGToggleChannelsDialogAction.NAME, LOCKABLE | SYNC_THREAD |SHORTCUT);
+		this.map(TGToggleBrowserAction.NAME, LOCKABLE | SYNC_THREAD |SHORTCUT);
+		this.map(TGToggleTransportDialogAction.NAME, LOCKABLE | SYNC_THREAD |SHORTCUT);
+		this.map(TGToggleMarkerListAction.NAME, LOCKABLE | SYNC_THREAD |SHORTCUT);
+		this.map(TGToggleMainToolbarAction.NAME, LOCKABLE | SYNC_THREAD |SHORTCUT);
+		this.map(TGToggleEditToolbarAction.NAME, LOCKABLE | SYNC_THREAD |SHORTCUT);
+		this.map(TGOpenDocumentationDialogAction.NAME, LOCKABLE | SYNC_THREAD |SHORTCUT);
+		this.map(TGOpenAboutDialogAction.NAME, LOCKABLE | SYNC_THREAD |SHORTCUT);
 	}
 	
 	private void map(String actionId, int flags) {
