@@ -1,8 +1,8 @@
 package org.herac.tuxguitar.app.view.dialog.keybindings;
 
-import org.herac.tuxguitar.app.system.keybindings.KeyBinding;
+import org.herac.tuxguitar.ui.resource.UIKeyConvination;
 
 public interface TGKeyBindingSelectorHandler {
 	
-	void handleSelection(KeyBinding kb);
+	void handleSelection(UIKeyConvination kb);
 }
