@@ -1,23 +1,24 @@
 package org.herac.tuxguitar.app.view.util;
 
-import org.eclipse.swt.widgets.Control;
+import org.herac.tuxguitar.ui.resource.UICursor;
+import org.herac.tuxguitar.ui.widget.UIControl;
 import org.herac.tuxguitar.util.TGContext;
 
 public class TGCursorController {
 	
 	private TGContext context;
 	private TGSyncProcess process;
-	private Control control;
-	private int cursorStyle;
+	private UIControl control;
+	private UICursor cursor;
 	
-	public TGCursorController(TGContext context, Control control) {
+	public TGCursorController(TGContext context, UIControl control) {
 		this.context = context;
 		this.control = control;
 		this.createSyncProcess();
 	}
 	
-	public void loadCursor(int cursorStyle) {
-		this.cursorStyle = cursorStyle;
+	public void loadCursor(UICursor cursor) {
+		this.cursor = cursor;
 		this.process.process();
 	}
 	
@@ -31,15 +32,15 @@ public class TGCursorController {
 	
 	private void updateCursor() {
 		if( this.isControlling(this.control)) {
-			this.control.setCursor(this.control.getDisplay().getSystemCursor(this.cursorStyle));
+			this.control.setCursor(this.cursor);
 		}
 	}
 
-	public Control getControl() {
+	public UIControl getControl() {
 		return control;
 	}
 	
-	public boolean isControlling(Control control) {
+	public boolean isControlling(UIControl control) {
 		if( control == null || control.isDisposed() ) {
 			return false;
 		}
